﻿using System;
using System.Collections.Generic;
using Tekla.Structures.Geometry3d;
using Tekla.Structures.Model;
using Tekla.Structures.Model.Operations;

namespace PlateBeamConverter
{
	// Token: 0x02000002 RID: 2
	internal static class AssociativeObjectsInsertion
	{
		// Token: 0x06000001 RID: 1 RVA: 0x00002318 File Offset: 0x00000518
		private static void AddBoltXyDistance(BoltArray createdBoltGroup, BoltArray boltGroupAsBoltArray)
		{
			int boltDistXCount = boltGroupAsBoltArray.GetBoltDistXCount();
			double boltDistX = boltGroupAsBoltArray.GetBoltDistX(boltDistXCount - 1);
			int boltDistYCount = boltGroupAsBoltArray.GetBoltDistYCount();
			double boltDistY = boltGroupAsBoltArray.GetBoltDistY(boltDistYCount - 1);
			for (int i = 0; i < boltDistXCount; i++)
			{
				createdBoltGroup.AddBoltDistX(boltDistX);
			}
			for (int j = 0; j < boltDistYCount; j++)
			{
				createdBoltGroup.AddBoltDistY(boltDistY);
			}
		}

		// Token: 0x06000002 RID: 2 RVA: 0x00002388 File Offset: 0x00000588
		private static void AddBoltXyDistance(BoltXYList createdBoltGroup, BoltXYList boltGroupAsBoltXyList)
		{
			int boltDistXCount = boltGroupAsBoltXyList.GetBoltDistXCount();
			double boltDistX = boltGroupAsBoltXyList.GetBoltDistX(boltDistXCount - 1);
			int boltDistYCount = boltGroupAsBoltXyList.GetBoltDistYCount();
			double boltDistY = boltGroupAsBoltXyList.GetBoltDistY(boltDistYCount - 1);
			for (int i = 0; i < boltDistXCount; i++)
			{
				createdBoltGroup.AddBoltDistX(boltDistX);
			}
			for (int j = 0; j < boltDistYCount; j++)
			{
				createdBoltGroup.AddBoltDistY(boltDistY);
			}
		}

		// Token: 0x06000003 RID: 3 RVA: 0x000023F8 File Offset: 0x000005F8
		private static BoltGroup CreateBoltGroup(BoltGroup createdBoltGroup, BoltGroup originalBoltGroup, ModelObject modelObject)
		{
			if (modelObject is Beam)
			{
				createdBoltGroup.PartToBeBolted = (modelObject as Beam);
				createdBoltGroup.PartToBoltTo = (modelObject as Beam);
			}
			else if (modelObject is PolyBeam)
			{
				createdBoltGroup.PartToBeBolted = (modelObject as PolyBeam);
				createdBoltGroup.PartToBoltTo = (modelObject as PolyBeam);
			}
			createdBoltGroup.FirstPosition = new Point(originalBoltGroup.FirstPosition);
			createdBoltGroup.SecondPosition = new Point(originalBoltGroup.SecondPosition);
			createdBoltGroup.BoltSize = originalBoltGroup.BoltSize;
			createdBoltGroup.Tolerance = originalBoltGroup.Tolerance;
			createdBoltGroup.BoltStandard = originalBoltGroup.BoltStandard;
			createdBoltGroup.BoltType = originalBoltGroup.BoltType;
			createdBoltGroup.CutLength = originalBoltGroup.CutLength;
			createdBoltGroup.Length = originalBoltGroup.Length;
			createdBoltGroup.ExtraLength = originalBoltGroup.ExtraLength;
			createdBoltGroup.ThreadInMaterial = originalBoltGroup.ThreadInMaterial;
			createdBoltGroup.StartPointOffset = originalBoltGroup.StartPointOffset;
			createdBoltGroup.EndPointOffset = originalBoltGroup.EndPointOffset;
			createdBoltGroup.Position.PlaneOffset = originalBoltGroup.Position.PlaneOffset;
			createdBoltGroup.Position.RotationOffset = originalBoltGroup.Position.RotationOffset;
			createdBoltGroup.Position.DepthOffset = originalBoltGroup.Position.DepthOffset;
			createdBoltGroup.Position.Depth = originalBoltGroup.Position.Depth;
			createdBoltGroup.Position.Plane = originalBoltGroup.Position.Plane;
			createdBoltGroup.Position.Rotation = originalBoltGroup.Position.Rotation;
			createdBoltGroup.Bolt = false;
			createdBoltGroup.Washer1 = originalBoltGroup.Washer1;
			createdBoltGroup.Washer2 = originalBoltGroup.Washer2;
			createdBoltGroup.Washer3 = originalBoltGroup.Washer3;
			createdBoltGroup.Nut1 = originalBoltGroup.Nut1;
			createdBoltGroup.Nut2 = originalBoltGroup.Nut1;
			createdBoltGroup.Hole1 = originalBoltGroup.Hole1;
			createdBoltGroup.Hole2 = originalBoltGroup.Hole2;
			createdBoltGroup.Hole3 = originalBoltGroup.Hole3;
			createdBoltGroup.Hole4 = originalBoltGroup.Hole4;
			createdBoltGroup.Hole5 = originalBoltGroup.Hole5;
			createdBoltGroup.SlottedHoleX = originalBoltGroup.SlottedHoleX;
			createdBoltGroup.SlottedHoleY = originalBoltGroup.SlottedHoleY;
			createdBoltGroup.RotateSlots = originalBoltGroup.RotateSlots;
			return createdBoltGroup;
		}

		// Token: 0x06000004 RID: 4 RVA: 0x00002648 File Offset: 0x00000848
		private static EdgeChamfer CreateEdgeChamfer(EdgeChamfer originalEdgeChamfer, ModelObject modelObject, Point firstEnd, Point secondEnd)
		{
			EdgeChamfer edgeChamfer = new EdgeChamfer
			{
				FirstChamferEndType = originalEdgeChamfer.FirstChamferEndType,
				SecondChamferEndType = originalEdgeChamfer.SecondChamferEndType,
				FirstBevelDimension = originalEdgeChamfer.FirstBevelDimension,
				SecondBevelDimension = originalEdgeChamfer.SecondBevelDimension,
				FirstEnd = new Point(firstEnd),
				SecondEnd = new Point(secondEnd)
			};
			edgeChamfer.Chamfer.X = originalEdgeChamfer.Chamfer.X;
			edgeChamfer.Chamfer.Y = originalEdgeChamfer.Chamfer.Y;
			edgeChamfer.Father = modelObject;
			return edgeChamfer;
		}

		// Token: 0x06000005 RID: 5 RVA: 0x000026E8 File Offset: 0x000008E8
		private static bool CreateOperativePart(BooleanPart createdBooleanPart, Part newOperativePart)
		{
			bool flag = false;
			bool result;
			if (newOperativePart != null && newOperativePart.Insert())
			{
				newOperativePart.Class = "BlOpCl";
				createdBooleanPart.SetOperativePart(newOperativePart);
				if (createdBooleanPart.Insert())
				{
					flag = true;
					if (!newOperativePart.Delete())
					{
						Utility.MessageList.Add("CreateOperativePart method fail: New Operative part deletion failed");
						Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_New_Operative_part_deletion_failed"));
					}
				}
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("CreateOperativePart method fail: Operative part insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Operative_part_insertion_failed"));
				result = flag;
			}
			return result;
		}

		// Token: 0x06000006 RID: 6 RVA: 0x00002794 File Offset: 0x00000994
		private static bool DeleteUnneededBoltGroup(BoltGroup createdBoltGroup)
		{
			bool result = false;
			Solid solid = new Beam
			{
				Identifier = createdBoltGroup.Identifier
			}.GetSolid(Solid.SolidCreationTypeEnum.HIGH_ACCURACY);
			Point p = new Point(0.0, 0.0, 0.0);
			if (solid.MaximumPoint == p && solid.MinimumPoint == p && !(result = createdBoltGroup.Delete()))
			{
				Utility.MessageList.Add("DeleteUnneededBoltGroup method fail: UnneededBoltGroup deletion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Unneeded_BoltGroup_deletion_failed"));
			}
			return result;
		}

		// Token: 0x06000007 RID: 7 RVA: 0x0000283C File Offset: 0x00000A3C
		private static bool InsertBooleanObjects(Tekla.Structures.Model.Boolean boolean, List<ModelObject> createdPlatesList)
		{
			bool result = false;
			foreach (ModelObject current in createdPlatesList)
			{
				if (boolean is CutPlane)
				{
					result = AssociativeObjectsInsertion.InsertCutPlane(boolean, current);
				}
				else if (boolean is EdgeChamfer)
				{
					if (AssociativeObjectsInsertion.InsertEdgeChamfer(boolean, current))
					{
						result = true;
					}
				}
				else if (boolean is Fitting)
				{
					result = AssociativeObjectsInsertion.InsertFitting(boolean, current);
				}
			}
			return result;
		}

		// Token: 0x06000008 RID: 8 RVA: 0x000028F8 File Offset: 0x00000AF8
		private static bool InsertBooleanPartAsBeam(BooleanPart createdBooleanPart, Part operativePartOfOriginalBooleanPart)
		{
			Beam newOperativePart = operativePartOfOriginalBooleanPart as Beam;
			bool result;
			if (!(result = AssociativeObjectsInsertion.CreateOperativePart(createdBooleanPart, newOperativePart)))
			{
				Utility.MessageList.Add("InsertBooleanPartAsBeam method fail: Boolean part as beam insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Boolean_part_as_beam_insertion_failed"));
			}
			return result;
		}

		// Token: 0x06000009 RID: 9 RVA: 0x00002948 File Offset: 0x00000B48
		private static bool InsertBooleanPartAsContourPlate(BooleanPart createdBooleanPart, Part operativePartOfOriginalBooleanPart)
		{
			ContourPlate newOperativePart = operativePartOfOriginalBooleanPart as ContourPlate;
			bool result;
			if (!(result = AssociativeObjectsInsertion.CreateOperativePart(createdBooleanPart, newOperativePart)))
			{
				Utility.MessageList.Add("InsertBooleanPartAsContourPlate method fail: Boolean part as contour plate insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Boolean_part_as_contour_plate_insertion_failed"));
			}
			return result;
		}

		// Token: 0x0600000A RID: 10 RVA: 0x00002998 File Offset: 0x00000B98
		private static bool InsertBooleanPartAsPolyBeam(BooleanPart createdBooleanPart, Part operativePartOfOriginalBooleanPart)
		{
			PolyBeam newOperativePart = operativePartOfOriginalBooleanPart as PolyBeam;
			bool result;
			if (!(result = AssociativeObjectsInsertion.CreateOperativePart(createdBooleanPart, newOperativePart)))
			{
				Utility.MessageList.Add("InsertBooleanPartAsPolyBeam method fail: Boolean part as poly beam insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Boolean_part_as_poly_beam_insertion_failed"));
			}
			return result;
		}

		// Token: 0x0600000B RID: 11 RVA: 0x000029E8 File Offset: 0x00000BE8
		private static bool InsertBooleanPartObjects(BooleanPart originalBooleanPart, List<ModelObject> createdPlatesList)
		{
			bool flag = false;
			Part operativePart = originalBooleanPart.OperativePart;
			foreach (ModelObject current in createdPlatesList)
			{
				BooleanPart createdBooleanPart = new BooleanPart
				{
					Father = current,
					Type = originalBooleanPart.Type
				};
				if (operativePart is Beam)
				{
					flag = AssociativeObjectsInsertion.InsertBooleanPartAsBeam(createdBooleanPart, operativePart);
				}
				else if (operativePart is PolyBeam)
				{
					flag = AssociativeObjectsInsertion.InsertBooleanPartAsPolyBeam(createdBooleanPart, operativePart);
				}
				else if (operativePart is ContourPlate)
				{
					flag = AssociativeObjectsInsertion.InsertBooleanPartAsContourPlate(createdBooleanPart, operativePart);
				}
			}
			if (!flag)
			{
				Utility.MessageList.Add("InsertBooleanPartObjects method fail: Boolean objects insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Boolean_objects_insertion_failed"));
			}
			return flag;
		}

		// Token: 0x0600000C RID: 12 RVA: 0x00002AF8 File Offset: 0x00000CF8
		private static bool InsertCutPlane(Tekla.Structures.Model.Boolean boolean, ModelObject modelObject)
		{
			CutPlane cutPlane = boolean as CutPlane;
			CutPlane cutPlane2 = new CutPlane();
			if (cutPlane != null)
			{
				cutPlane2.Plane = cutPlane.Plane;
			}
			cutPlane2.Father = modelObject;
			bool result;
			if (!(result = cutPlane2.Insert()))
			{
				Utility.MessageList.Add("InsertCutPlane method fail: CutPlane insertion failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_CutPlane_insertion_failed"));
			}
			return result;
		}

		// Token: 0x0600000D RID: 13 RVA: 0x00002B70 File Offset: 0x00000D70
		private static bool InsertEdgeChamfer(Tekla.Structures.Model.Boolean boolean, ModelObject modelObject)
		{
			bool flag = false;
			EdgeChamfer edgeChamfer = boolean as EdgeChamfer;
			bool result;
			if (edgeChamfer != null)
			{
				Point firstEnd = edgeChamfer.FirstEnd;
				Point secondEnd = edgeChamfer.SecondEnd;
				EdgeChamfer edgeChamfer2 = AssociativeObjectsInsertion.CreateEdgeChamfer(edgeChamfer, modelObject, firstEnd, secondEnd);
				if (!edgeChamfer2.Insert())
				{
					result = flag;
					return result;
				}
				flag = true;
				edgeChamfer2.Select();
				Point p = new Point(edgeChamfer2.FirstEnd);
				Point p2 = new Point(edgeChamfer2.SecondEnd);
				bool flag2 = edgeChamfer.FirstEnd != p;
				bool flag3 = edgeChamfer.SecondEnd != p2;
				if (!flag2 && !flag3)
				{
					result = flag;
					return result;
				}
				if (!edgeChamfer2.Delete())
				{
					Utility.MessageList.Add("InsertEdgeChamfer method fail: Not needed EdgeChamfer deletion failed");
					Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Not_needed_EdgeChamfer_deletion_failed"));
				}
			}
			result = flag;
			return result;
		}

		// Token: 0x0600000E RID: 14 RVA: 0x00002C5C File Offset: 0x00000E5C
		private static bool InsertFitting(Tekla.Structures.Model.Boolean boolean, ModelObject modelObject)
		{
			bool result = false;
			Fitting fitting = boolean as Fitting;
			Fitting fitting2 = new Fitting();
			if (fitting != null)
			{
				fitting2.Plane = fitting.Plane;
				fitting2.Father = modelObject;
				if (!(result = fitting2.Insert()))
				{
					Utility.MessageList.Add("InsertFitting method fail: Fitting insertion failed");
					Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Fitting_insertion_failed"));
				}
			}
			return result;
		}

		// Token: 0x0600000F RID: 15 RVA: 0x00002CD4 File Offset: 0x00000ED4
		public static bool InsertObjects(this Tekla.Structures.Model.Boolean boolean, List<ModelObject> createdPlatesList, CoordinateSystem coordinateSystemForEdgeInsertion)
		{
			return boolean != null && AssociativeObjectsInsertion.InsertBooleanObjects(boolean, createdPlatesList);
		}

		// Token: 0x06000010 RID: 16 RVA: 0x00002D00 File Offset: 0x00000F00
		public static bool InsertObjects(this BooleanPart originalBooleanPart, List<ModelObject> createdPlatesList, CoordinateSystem plateBeamsGeneralCoordinateSystem)
		{
			return originalBooleanPart != null && AssociativeObjectsInsertion.InsertBooleanPartObjects(originalBooleanPart, createdPlatesList);
		}

		// Token: 0x06000011 RID: 17 RVA: 0x00002D2C File Offset: 0x00000F2C
		private static bool ReMapBoltGroupObjects(BoltGroup boltGroup, List<ModelObject> createdPlatesList, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			foreach (ModelObject current in createdPlatesList)
			{
				if (boltGroup is BoltArray)
				{
					if (AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltArrayHole(boltGroup, current as Part, originalBeamProperties))
					{
						result = true;
					}
				}
				else if (boltGroup is BoltCircle)
				{
					if (AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltCircleHole(boltGroup, current as Part, originalBeamProperties))
					{
						result = true;
					}
				}
				else if (boltGroup is BoltXYList && AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltXyListHole(boltGroup, current as Part, originalBeamProperties))
				{
					result = true;
				}
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
			return result;
		}

		// Token: 0x06000012 RID: 18 RVA: 0x00002E34 File Offset: 0x00001034
		private static bool ReMapBoltGroupObjects(BoltGroup boltGroup, List<ModelObject> createdPlatesList, OriginalPolyBeamProperties originalBeamProperties)
		{
			bool result = false;
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			foreach (ModelObject current in createdPlatesList)
			{
				if (boltGroup is BoltArray)
				{
					if (AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltArrayHole(boltGroup, current as Part, originalBeamProperties))
					{
						result = true;
					}
				}
				else if (boltGroup is BoltCircle)
				{
					if (AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltCircleHole(boltGroup, current as Part, originalBeamProperties))
					{
						result = true;
					}
				}
				else if (boltGroup is BoltXYList && AssociativeObjectsInsertion.RemapBoltGroupUsingFakeBoltXyListHole(boltGroup, current as Part, originalBeamProperties))
				{
					result = true;
				}
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
			return result;
		}

		// Token: 0x06000013 RID: 19 RVA: 0x00002F3C File Offset: 0x0000113C
		private static bool RemapBoltGroupUsingFakeBoltArrayHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			BoltArray boltArray = originalBoltGroup as BoltArray;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltArray createdBoltGroup = new BoltArray();
			BoltArray boltArray2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltArray, plateBeam) as BoltArray;
			if (boltArray2 != null)
			{
				AssociativeObjectsInsertion.AddBoltXyDistance(boltArray2, boltArray);
				if (boltArray2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltArray2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalBoltArray(originalBoltGroup, plateBeam, originalBeamProperties, partToBeBolted, partToBoltTo);
					boltArray2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000014 RID: 20 RVA: 0x00002FCC File Offset: 0x000011CC
		private static bool RemapBoltGroupUsingFakeBoltArrayHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			bool result = false;
			BoltArray boltArray = originalBoltGroup as BoltArray;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltArray createdBoltGroup = new BoltArray();
			BoltArray boltArray2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltArray, plateBeam) as BoltArray;
			if (boltArray2 != null)
			{
				AssociativeObjectsInsertion.AddBoltXyDistance(boltArray2, boltArray);
				if (boltArray2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltArray2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalBoltArray(originalBoltGroup, plateBeam, originalPolyBeamProperties, partToBeBolted, partToBoltTo);
					boltArray2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000015 RID: 21 RVA: 0x0000305C File Offset: 0x0000125C
		private static bool RemapBoltGroupUsingFakeBoltCircleHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			BoltCircle boltCircle = originalBoltGroup as BoltCircle;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltCircle createdBoltGroup = new BoltCircle();
			BoltCircle boltCircle2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltCircle, plateBeam) as BoltCircle;
			if (boltCircle2 != null)
			{
				if (boltCircle != null)
				{
					boltCircle2.NumberOfBolts = boltCircle.NumberOfBolts;
					boltCircle2.Diameter = boltCircle.Diameter;
				}
				if (boltCircle2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltCircle2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalBoltCircle(originalBoltGroup, plateBeam, originalBeamProperties, partToBeBolted, partToBoltTo);
					boltCircle2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000016 RID: 22 RVA: 0x0000310C File Offset: 0x0000130C
		private static bool RemapBoltGroupUsingFakeBoltCircleHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			bool result = false;
			BoltCircle boltCircle = originalBoltGroup as BoltCircle;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltCircle createdBoltGroup = new BoltCircle();
			BoltCircle boltCircle2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltCircle, plateBeam) as BoltCircle;
			if (boltCircle2 != null)
			{
				if (boltCircle != null)
				{
					boltCircle2.NumberOfBolts = boltCircle.NumberOfBolts;
					boltCircle2.Diameter = boltCircle.Diameter;
				}
				if (boltCircle2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltCircle2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalBoltCircle(originalBoltGroup, plateBeam, originalPolyBeamProperties, partToBeBolted, partToBoltTo);
					boltCircle2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000017 RID: 23 RVA: 0x000031BC File Offset: 0x000013BC
		private static bool RemapBoltGroupUsingFakeBoltXyListHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			BoltXYList boltXYList = originalBoltGroup as BoltXYList;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltXYList createdBoltGroup = new BoltXYList();
			BoltXYList boltXYList2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltXYList, plateBeam) as BoltXYList;
			if (boltXYList2 != null)
			{
				AssociativeObjectsInsertion.AddBoltXyDistance(boltXYList2, boltXYList);
				if (boltXYList2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltXYList2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalXyList(originalBoltGroup, plateBeam, originalBeamProperties, partToBeBolted, partToBoltTo);
					boltXYList2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000018 RID: 24 RVA: 0x0000324C File Offset: 0x0000144C
		private static bool RemapBoltGroupUsingFakeBoltXyListHole(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			bool result = false;
			BoltXYList boltXYList = originalBoltGroup as BoltXYList;
			Part partToBeBolted = originalBoltGroup.PartToBeBolted;
			Part partToBoltTo = originalBoltGroup.PartToBoltTo;
			plateBeam.Select();
			BoltXYList createdBoltGroup = new BoltXYList();
			BoltXYList boltXYList2 = AssociativeObjectsInsertion.CreateBoltGroup(createdBoltGroup, boltXYList, plateBeam) as BoltXYList;
			if (boltXYList2 != null)
			{
				AssociativeObjectsInsertion.AddBoltXyDistance(boltXYList2, boltXYList);
				if (boltXYList2.Insert() && !AssociativeObjectsInsertion.DeleteUnneededBoltGroup(boltXYList2))
				{
					result = AssociativeObjectsInsertion.ReMapOriginalXyList(originalBoltGroup, plateBeam, originalPolyBeamProperties, partToBeBolted, partToBoltTo);
					boltXYList2.Delete();
				}
			}
			return result;
		}

		// Token: 0x06000019 RID: 25 RVA: 0x000032DC File Offset: 0x000014DC
		public static bool ReMapObjects(this BoltGroup boltGroup, List<ModelObject> createdPlatesList, CoordinateSystem plateBeamsGeneralCoordinateSystem, OriginalBeamProperties originalBeamProperties)
		{
			return boltGroup != null && AssociativeObjectsInsertion.ReMapBoltGroupObjects(boltGroup, createdPlatesList, originalBeamProperties);
		}

		// Token: 0x0600001A RID: 26 RVA: 0x00003308 File Offset: 0x00001508
		public static bool ReMapObjects(this BoltGroup boltGroup, List<ModelObject> createdPlatesList, CoordinateSystem plateBeamsGeneralCoordinateSystem, OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			return boltGroup != null && AssociativeObjectsInsertion.ReMapBoltGroupObjects(boltGroup, createdPlatesList, originalPolyBeamProperties);
		}

		// Token: 0x0600001B RID: 27 RVA: 0x00003334 File Offset: 0x00001534
		private static bool ReMapOriginalBoltArray(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("ReMapOriginalBoltArray method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}

		// Token: 0x0600001C RID: 28 RVA: 0x00003438 File Offset: 0x00001638
		private static bool ReMapOriginalBoltArray(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalPolyBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalPolyBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalPolyBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("ReMapOriginalBoltArray method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}

		// Token: 0x0600001D RID: 29 RVA: 0x0000353C File Offset: 0x0000173C
		private static bool ReMapOriginalBoltCircle(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("ReMapOriginalBoltCircle method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}

		// Token: 0x0600001E RID: 30 RVA: 0x00003640 File Offset: 0x00001840
		private static bool ReMapOriginalBoltCircle(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("ReMapOriginalBoltCircle method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}

		// Token: 0x0600001F RID: 31 RVA: 0x00003744 File Offset: 0x00001944
		private static bool ReMapOriginalXyList(BoltGroup originalBoltGroup, Part plateBeam, OriginalBeamProperties originalBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("RemapBoltGroupUsingFakeBoltXyListHole method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}

		// Token: 0x06000020 RID: 32 RVA: 0x00003848 File Offset: 0x00001A48
		private static bool ReMapOriginalXyList(BoltGroup originalBoltGroup, Part plateBeam, OriginalPolyBeamProperties originalBeamProperties, Part partToBeBolted, Part partToBoltTo)
		{
			if (originalBoltGroup.PartToBoltTo.ToString() != originalBoltGroup.PartToBeBolted.ToString())
			{
				if (partToBeBolted.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBeBolted = plateBeam;
					originalBoltGroup.PartToBoltTo = partToBoltTo;
				}
				else if (partToBoltTo.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalBoltGroup.PartToBoltTo = plateBeam;
					originalBoltGroup.PartToBeBolted = partToBeBolted;
				}
			}
			else
			{
				originalBoltGroup.PartToBoltTo = plateBeam;
				originalBoltGroup.PartToBeBolted = plateBeam;
			}
			bool result;
			if (!(result = originalBoltGroup.Modify()))
			{
				Utility.MessageList.Add("RemapBoltGroupUsingFakeBoltXyListHole method fail: Re mapping failed");
				Operation.DisplayPrompt(LocalizationTools.Localization.GetText("albl_Bolt_group_re_mapping_failed"));
			}
			return result;
		}
	}
}
