﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.Win32;
using Tekla.Structures;
using Tekla.Structures.Dialog;
using Tekla.Structures.Dialog.UIControls;
using Tekla.Structures.Model;
using Tekla.Structures.Model.Operations;
using Tekla.Structures.Model.UI;

namespace PlateBeamConverter
{
	// Token: 0x0200000D RID: 13
	public partial class Attributes : ApplicationFormBase
	{
		// Token: 0x0600009C RID: 156 RVA: 0x00006370 File Offset: 0x00004570
		public Attributes()
		{
			Attributes.ReportProgressBackgroundWorker.WorkerReportsProgress = true;
			this.InitializeComponent();
			base.InitializeForm();
			base.ShowInTaskbar = true;
			this.InitializeHelpLink();
			Attributes.LoadWeldAttributes(ref this.comboBoxWeldAttributes);
			Attributes.messageLabel = new Label();
			Attributes.messageLabel.TextChanged += new EventHandler(this.MessageLabelTextChanged);
			PlateBeamConverterTools.WorkingModel = new Model();
			PlateBeamConverterTools.WorkingModelObjectSelector = new Tekla.Structures.Model.UI.ModelObjectSelector();
		}

		// Token: 0x0600009D RID: 157 RVA: 0x000063F4 File Offset: 0x000045F4
		private static bool ArePartsPicked(out ModelObjectEnumerator partsOut, string message)
		{
			bool result = false;
			Picker picker = new Picker();
			ModelObjectEnumerator modelObjectEnumerator = null;
			try
			{
				modelObjectEnumerator = picker.PickObjects(Picker.PickObjectsEnum.PICK_N_PARTS, message);
			}
			catch (ApplicationException ex)
			{
				if (ex.Message != "User interrupt")
				{
					throw;
				}
			}
			if (modelObjectEnumerator != null && modelObjectEnumerator.GetSize() > 0)
			{
				result = true;
			}
			else
			{
				Utility.MessageList.Add("ArePartsPicked method fail: SelectedParts are null");
			}
			partsOut = modelObjectEnumerator;
			return result;
		}

		// Token: 0x0600009E RID: 158 RVA: 0x0000216E File Offset: 0x0000036E
		private void AttributesFormClosing(object sender, FormClosingEventArgs e)
		{
			SystemEvents.UserPreferenceChanged -= new UserPreferenceChangedEventHandler(this.SystemEventsUserPreferenceChanged);
		}

		// Token: 0x0600009F RID: 159 RVA: 0x00002183 File Offset: 0x00000383
		private void AttributesLoad(object sender, EventArgs e)
		{
			LocalizationTools.LocalizeForm(this);
			this.StartTimer();
		}

		// Token: 0x060000A0 RID: 160 RVA: 0x00002194 File Offset: 0x00000394
		private void ButtonCancelClick(object sender, EventArgs e)
		{
			base.Close();
		}

		// Token: 0x060000A1 RID: 161 RVA: 0x0000219E File Offset: 0x0000039E
		private void ButtonCreateClick(object sender, EventArgs e)
		{
			this.RunThePlateBeamConverterApplication();
		}

		// Token: 0x060000A3 RID: 163 RVA: 0x000064C0 File Offset: 0x000046C0
		private void FormLayout(object sender, LayoutEventArgs e)
		{
			if (base.WindowState == FormWindowState.Minimized && !TeklaStructures.MainWindow.IsMinimized)
			{
				this.isMinimized = true;
			}
			else if (base.WindowState == FormWindowState.Normal && !TeklaStructures.MainWindow.IsMinimized)
			{
				this.isMinimized = false;
			}
		}

		// Token: 0x060000A4 RID: 164 RVA: 0x00006518 File Offset: 0x00004718
		private static void GetAttributes(string extension, ref ComboBox attributeComboBox)
		{
			List<string> multiDirectoryFileList = EnvironmentFiles.GetMultiDirectoryFileList(EnvironmentFiles.GetStandardPropertyFileDirectories(), extension);
			if (multiDirectoryFileList != null)
			{
				attributeComboBox.Items.AddRange(multiDirectoryFileList.ToArray());
			}
		}

		// Token: 0x060000A6 RID: 166 RVA: 0x000021A8 File Offset: 0x000003A8
		private void InitializeHelpLink()
		{
			this.customSaveLoad1.HelpFileType = CustomSaveLoad.HelpFileTypeEnum.General;
			this.customSaveLoad1.HelpUrl = string.Empty;
			this.customSaveLoad1.HelpKeyword = "ext_plate_beam_converter";
		}

		// Token: 0x060000A7 RID: 167 RVA: 0x000021DA File Offset: 0x000003DA
		public static void LoadWeldAttributes(ref ComboBox weldAttributesComboBox)
		{
			Attributes.GetAttributes("wld", ref weldAttributesComboBox);
		}

		// Token: 0x060000A8 RID: 168 RVA: 0x00007224 File Offset: 0x00005424
		private static bool MainSelectionMethod(out ModelObjectEnumerator selectedPartsEnum)
		{
			string text = TeklaStructures.Environment.Localization.GetText("albl_Selection_cancelled");
			string text2 = LocalizationTools.Localization.GetText("选择梁或柱，并以鼠标中键结束");
			Attributes.ShowMessage(text2);
			bool result;
			if (!(result = Attributes.ArePartsPicked(out selectedPartsEnum, text2)))
			{
				Attributes.ShowMessage(text);
			}
			return result;
		}

		// Token: 0x060000A9 RID: 169 RVA: 0x0000727C File Offset: 0x0000547C
		private void MainWorkMethod(ModelObjectEnumerator selectedPartsEnum, string platesPrefix, string assemblePrefix, string weldsAttributeFileName)
		{
			RunWorkerCompletedEventHandler runWorkerCompletedEventHandler = null;
			try
			{
				List<ModelObject> verifiedPartsListOut = new List<ModelObject>();
				PlateBeamConverterTools.EliminateDuplicatesAndNotBeamsOrPolyBeams(selectedPartsEnum, ref verifiedPartsListOut);
				if (verifiedPartsListOut.Count == 0)
				{
					Attributes.ShowMessage(LocalizationTools.Localization.GetText("被选择的零件不是梁或柱"));
				}
				else
				{
					this.toolStripProgressBar1.Visible = true;
					int partTotal = verifiedPartsListOut.Count;
					int partCounter = 1;
					int progress = 0;
					Attributes.ReportProgressBackgroundWorker.DoWork += delegate(object sender, DoWorkEventArgs e)
					{
						Utility.MessageList.Clear();
						foreach (ModelObject current in verifiedPartsListOut)
						{
							string text = TeklaStructures.Environment.Localization.GetText("创建中……");
							if (current is Beam)
							{
								Beam selectedBeam = current as Beam;
								Attributes.ShowMessage(text);
								PlateBeamConverterTools.CreateBuiltUpSectionPlatesMainMethod(selectedBeam, platesPrefix, assemblePrefix, weldsAttributeFileName);
							}
							progress = (int)(100.0 * (double)partCounter / (double)partTotal);
							Attributes.ReportProgressBackgroundWorker.ReportProgress(progress);
							partCounter++;
						}
					};
					Attributes.ReportProgressBackgroundWorker.ProgressChanged += delegate(object sender, ProgressChangedEventArgs e)
					{
						if (progress > 100)
						{
							progress = 100;
						}
						if (!this.IsDisposed)
						{
							this.toolStripProgressBar1.Value = progress;
						}
					};
					if (runWorkerCompletedEventHandler == null)
					{
						runWorkerCompletedEventHandler = delegate(object sender, RunWorkerCompletedEventArgs e)
						{
							this.toolStripProgressBar1.Visible = false;
							string text = LocalizationTools.Localization.GetText("板梁创建");
							if (Utility.MessageList.Count > 0)
							{
								text = TeklaStructures.Environment.Localization.GetText("发生了错误，请看错误日志");
								Utility.CreateErrorReport();
								text = text + ": " + Utility.ReportName;
							}
							Attributes.ShowMessage(text);
						};
					}
					Attributes.ReportProgressBackgroundWorker.RunWorkerCompleted += runWorkerCompletedEventHandler;
					if (!Attributes.ReportProgressBackgroundWorker.IsBusy)
					{
						Attributes.ReportProgressBackgroundWorker.RunWorkerAsync();
					}
				}
			}
			catch (Exception)
			{
				Attributes.ShowMessage(LocalizationTools.Localization.GetText("板梁创建失败"));
			}
		}

		// Token: 0x060000AA RID: 170 RVA: 0x000021E9 File Offset: 0x000003E9
		private void MessageLabelTextChanged(object sender, EventArgs e)
		{
			this.toolStripStatusLabel1.Text = TeklaStructures.Environment.Localization.GetText(Attributes.messageLabel.Text);
		}

		// Token: 0x060000AB RID: 171 RVA: 0x00002211 File Offset: 0x00000411
		protected override void OnHelpRequested(HelpEventArgs hevent)
		{
//			HelpViewer.DisplayHelpTopic("ext_plate_beam_converter");
//			hevent.Handled = true;
		}

		// Token: 0x060000AC RID: 172 RVA: 0x00007400 File Offset: 0x00005600
		private void RunThePlateBeamConverterApplication()
		{
			ModelObjectEnumerator selectedPartsEnum;
			if (Attributes.MainSelectionMethod(out selectedPartsEnum))
			{
				string text = this.textBoxPlatesPrefix.Text;
				string text2 = this.textBoxAssemblePrefix.Text;
				string text3 = this.comboBoxWeldAttributes.Text;
				this.MainWorkMethod(selectedPartsEnum, text, text2, text3);
			}
		}

		// Token: 0x060000AD RID: 173 RVA: 0x00002227 File Offset: 0x00000427
		public static void ShowMessage(string message)
		{
			Attributes.MessageLabel.Text = message;
			Operation.DisplayPrompt(message);
		}

		// Token: 0x060000AE RID: 174 RVA: 0x00007450 File Offset: 0x00005650
		private void StartTimer()
		{
			if (!this.TeklaStructuresStatus.Enabled)
			{
				this.TeklaStructuresStatus.Start();
			}
		}

		// Token: 0x060000AF RID: 175 RVA: 0x0000747C File Offset: 0x0000567C
		private void SystemEventsUserPreferenceChanged(object sender, UserPreferenceChangedEventArgs e)
		{
			if (e.Category == UserPreferenceCategory.Window)
			{
				this.Font = SystemFonts.MessageBoxFont;
			}
		}

		// Token: 0x060000B0 RID: 176 RVA: 0x000074AC File Offset: 0x000056AC
		private void TeklaStructuresStatusTick(object sender, EventArgs e)
		{
			if (!TeklaStructures.IsRunning)
			{
				base.Close();
			}
			else if (TeklaStructures.MainWindow.IsMinimized && base.WindowState == FormWindowState.Normal)
			{
				this.isMinimized = false;
				base.WindowState = FormWindowState.Minimized;
			}
			else if (!TeklaStructures.MainWindow.IsMinimized && base.WindowState == FormWindowState.Minimized && !this.isMinimized)
			{
				base.WindowState = FormWindowState.Normal;
			}
			else if (!TeklaStructures.MainWindow.IsMinimized && base.WindowState == FormWindowState.Minimized && this.isMinimized)
			{
				base.WindowState = FormWindowState.Minimized;
			}
		}

		// Token: 0x17000021 RID: 33
		// (get) Token: 0x060000B1 RID: 177 RVA: 0x00007564 File Offset: 0x00005764
		// (set) Token: 0x060000B2 RID: 178 RVA: 0x0000223D File Offset: 0x0000043D
		public static Label MessageLabel
		{
			get
			{
				return Attributes.messageLabel;
			}
			set
			{
				Attributes.messageLabel = value;
			}
		}

		// Token: 0x17000022 RID: 34
		// (get) Token: 0x060000B3 RID: 179 RVA: 0x0000757C File Offset: 0x0000577C
		// (set) Token: 0x060000B4 RID: 180 RVA: 0x00002246 File Offset: 0x00000446
		public static BackgroundWorker ReportProgressBackgroundWorker
		{
			get
			{
				return Attributes.backgroundWorkerForReportingProgress;
			}
			set
			{
				Attributes.backgroundWorkerForReportingProgress = value;
			}
		}

		// Token: 0x04000069 RID: 105
		private const string HelpPath = "ext_plate_beam_converter";

		// Token: 0x0400006A RID: 106
		private static BackgroundWorker backgroundWorkerForReportingProgress = new BackgroundWorker();

		// Token: 0x0400006D RID: 109
		private bool isMinimized;

		// Token: 0x0400006E RID: 110
		private static Label messageLabel;
	}
}
