﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Threading;
using Tekla.Structures;
using Tekla.Structures.Geometry3d;
using Tekla.Structures.Model;
using Tekla.Structures.Model.Operations;
using Tekla.Structures.Model.UI;
using Tekla.Structures.Plugins;

namespace PlateBeamConverter
{
	// Token: 0x02000012 RID: 18
	public class PlateBeamConverterTools
	{
		// Token: 0x060000C2 RID: 194 RVA: 0x00007BB0 File Offset: 0x00005DB0
		private static void AddCreatedPlateBeamsToList(PlateBeamConverterTools.ProfileTypes profileType, List<ModelObject> modelObjects, ModelObject upperFlangePlate, ModelObject webPlate, ModelObject webPlate2, ModelObject lowerFlangePlate)
		{
			switch (profileType)
			{
			case PlateBeamConverterTools.ProfileTypes.ProfileI:
			case PlateBeamConverterTools.ProfileTypes.ProfileCorU:
				modelObjects.Add(webPlate);
				modelObjects.Add(upperFlangePlate);
				modelObjects.Add(lowerFlangePlate);
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileT:
				modelObjects.Add(webPlate);
				modelObjects.Add(upperFlangePlate);
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection:
				modelObjects.Add(webPlate);
				modelObjects.Add(upperFlangePlate);
				modelObjects.Add(lowerFlangePlate);
				modelObjects.Add(webPlate2);
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileAngle:
				modelObjects.Add(webPlate);
				modelObjects.Add(lowerFlangePlate);
				break;
			}
		}

		// Token: 0x060000C3 RID: 195 RVA: 0x00007C40 File Offset: 0x00005E40
		private static void AddToAssociativeList(ModelObjectEnumerator objectEnumerator, ref List<ModelObject> objectList)
		{
			foreach (ModelObject item in objectEnumerator)
			{
				objectList.Add(item);
			}
		}

		// Token: 0x060000C4 RID: 196 RVA: 0x00007CA4 File Offset: 0x00005EA4
		private static double BeamLength(CoordinateSystem plateBeamsGeneralCoordinateSystem)
		{
			double x = plateBeamsGeneralCoordinateSystem.AxisX.X;
			double y = plateBeamsGeneralCoordinateSystem.AxisX.Y;
			double z = plateBeamsGeneralCoordinateSystem.AxisX.Z;
			return Math.Sqrt(Math.Pow(x, 2.0) + Math.Pow(y, 2.0) + Math.Pow(z, 2.0));
		}

		// Token: 0x060000C5 RID: 197 RVA: 0x00007D10 File Offset: 0x00005F10
		private static ArrayList CalculateContourPoints(List<LineSegment> lineSegmentList)
		{
			ArrayList arrayList = new ArrayList();
			for (int i = 0; i <= lineSegmentList.Count - 1; i++)
			{
				if (i == 0)
				{
					LineSegment lineSegment = lineSegmentList[i];
					ContourPoint value = new ContourPoint(lineSegment.Point1, null);
					arrayList.Add(value);
				}
				if (i == lineSegmentList.Count - 1)
				{
					LineSegment lineSegment2 = lineSegmentList[i];
					ContourPoint value2 = new ContourPoint(lineSegment2.Point2, null);
					arrayList.Add(value2);
				}
				else
				{
					LineSegment lineSegment3 = lineSegmentList[i];
					Line line = new Line(lineSegment3);
					LineSegment lineSegment4 = lineSegmentList[i + 1];
					Line line2 = new Line(lineSegment4);
					LineSegment lineSegment5 = Intersection.LineToLine(line, line2);
					if (lineSegment5 != null)
					{
						ContourPoint value3 = new ContourPoint(lineSegment5.Point1, null);
						arrayList.Add(value3);
					}
				}
			}
			return arrayList;
		}

		// Token: 0x060000C6 RID: 198 RVA: 0x00007E14 File Offset: 0x00006014
		private static void CalculateLowerFlangePlateStartAndEndPoint(OriginalBeamProperties originalBeamProperties, double beamLength, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType, double beamHeight, Beam lowerFlangePlate)
		{
			bool flag = subType == PlateBeamConverterTools.ProfileISubTypes.Tapered && PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties);
			bool flag2 = subType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges && PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties);
			if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				if (!flag && !flag2)
				{
					lowerFlangePlate.StartPoint = new Point(0.0, -beamHeight / 2.0, 0.0);
					lowerFlangePlate.EndPoint = new Point(beamLength, -beamHeight / 2.0, 0.0);
				}
				else
				{
					lowerFlangePlate.StartPoint = new Point(0.0, -originalBeamProperties.BeamHeight2 / 2.0, 0.0);
					lowerFlangePlate.EndPoint = new Point(beamLength, -originalBeamProperties.BeamHeight2 / 2.0, 0.0);
				}
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT)
			{
				lowerFlangePlate.StartPoint = new Point(0.0, -beamHeight / 2.0, 0.0);
				lowerFlangePlate.EndPoint = new Point(beamLength, -beamHeight / 2.0, 0.0);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileCorU || profileType == PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection || profileType == PlateBeamConverterTools.ProfileTypes.ProfileAngle)
			{
				lowerFlangePlate.StartPoint = new Point(0.0, -beamHeight / 2.0, 0.0);
				lowerFlangePlate.EndPoint = new Point(beamLength, -beamHeight / 2.0, 0.0);
			}
		}

		// Token: 0x060000C7 RID: 199 RVA: 0x00007FDC File Offset: 0x000061DC
		private static ArrayList CalculatePointsForITProfiles(OriginalPolyBeamProperties properties, PlateBeamConverterTools.ProfileTypes profileType, bool isDistanceOnPositiveAxe, bool isWebPlate, bool useLowerHeight)
		{
			double num = 0.0;
			double num2 = properties.PolyBeamHeight;
			double polyBeamHeight = properties.PolyBeamHeight1;
			double polyBeamHeight2 = properties.PolyBeamHeight2;
			if (num2 == 0.0)
			{
				num2 = PlateBeamConverterTools.IdentifyTheBiggerValue(polyBeamHeight, polyBeamHeight2);
				if (useLowerHeight)
				{
					num2 = 0.0;
				}
			}
			double num3 = num2 / 2.0;
			double num4 = properties.PolyBeamFlangeThickness;
			if (num4 == 0.0)
			{
				num4 = properties.PolyBeamPlateFlangeThickness;
				if (num4 == 0.0)
				{
					num4 = properties.PolyBeamFlangeThickness1;
				}
			}
			double num5 = num3 - num4;
			if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT && isWebPlate)
			{
				num5 = num3;
			}
			List<LineSegment> list = new List<LineSegment>();
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			for (int i = 0; i < properties.PolyBeamSegmentCoordinateSystems.Count; i++)
			{
				CoordinateSystem coordinateSystem = properties.PolyBeamSegmentCoordinateSystems[i] as CoordinateSystem;
				if (coordinateSystem != null)
				{
					TransformationPlane transformationPlane = new TransformationPlane(coordinateSystem);
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(transformationPlane);
					CoordinateSystem polyBeamCoordinateSystem = properties.PolyBeamCoordinateSystem;
					TransformationPlane transformationPlane2 = new TransformationPlane(polyBeamCoordinateSystem);
					Point point = new Point(transformationPlane2.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(polyBeamCoordinateSystem.Origin)));
					Point p = new Point();
					Point p2 = new Point();
					if (properties.PolyBeamPosition.Plane == Position.PlaneEnum.MIDDLE)
					{
						if (properties.PolyBeamPosition.Rotation != Position.RotationEnum.TOP && properties.PolyBeamPosition.Rotation != Position.RotationEnum.BELOW)
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT || properties.PolyBeamPosition.Rotation == Position.RotationEnum.BACK)
							{
								if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT)
								{
									if (isDistanceOnPositiveAxe)
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z - num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z + num5;
											break;
										}
									}
									else
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z + num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z - num5;
											break;
										}
									}
								}
								else if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z + num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z + num5;
										break;
									}
								}
								p = new Point(0.0, 0.0, num);
								p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), 0.0, num);
							}
						}
						else
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.TOP)
							{
								if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Y + num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Y - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y + num5;
										break;
									}
								}
							}
							else if (isDistanceOnPositiveAxe)
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y - num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y + num5;
									break;
								}
							}
							else
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y + num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y - num5;
									break;
								}
							}
							p = new Point(0.0, num, 0.0);
							p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), num, 0.0);
						}
					}
					else if (properties.PolyBeamPosition.Plane == Position.PlaneEnum.LEFT)
					{
						if (properties.PolyBeamPosition.Rotation != Position.RotationEnum.TOP && properties.PolyBeamPosition.Rotation != Position.RotationEnum.BELOW)
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT || properties.PolyBeamPosition.Rotation == Position.RotationEnum.BACK)
							{
								if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT)
								{
									if (isDistanceOnPositiveAxe)
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z - num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z + num5;
											break;
										}
									}
									else
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z + num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z - num5;
											break;
										}
									}
								}
								else if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z + num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z + num5;
										break;
									}
								}
								p = new Point(0.0, 0.0, num);
								p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), 0.0, num);
							}
						}
						else
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.TOP)
							{
								if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Y - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y + num5;
										break;
									}
								}
							}
							else if (isDistanceOnPositiveAxe)
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y - num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y + num5;
									break;
								}
							}
							else
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y + num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y - num5;
									break;
								}
							}
							p = new Point(0.0, num, 0.0);
							p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), num, 0.0);
						}
					}
					else if (properties.PolyBeamPosition.Plane == Position.PlaneEnum.RIGHT)
					{
						if (properties.PolyBeamPosition.Rotation != Position.RotationEnum.TOP && properties.PolyBeamPosition.Rotation != Position.RotationEnum.BELOW)
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT || properties.PolyBeamPosition.Rotation == Position.RotationEnum.BACK)
							{
								if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT)
								{
									if (isDistanceOnPositiveAxe)
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z - num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z + num5;
											break;
										}
									}
									else
									{
										switch (properties.PolyBeamPosition.Depth)
										{
										case Position.DepthEnum.FRONT:
											num = point.Z + num5;
											break;
										case Position.DepthEnum.BEHIND:
											num = point.Z - num5;
											break;
										}
									}
								}
								else if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z + num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Z - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Z + num5;
										break;
									}
								}
								p = new Point(0.0, 0.0, num);
								p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), 0.0, num);
							}
						}
						else
						{
							if (properties.PolyBeamPosition.Rotation == Position.RotationEnum.TOP)
							{
								if (isDistanceOnPositiveAxe)
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y - num5;
										break;
									}
								}
								else
								{
									switch (properties.PolyBeamPosition.Depth)
									{
									case Position.DepthEnum.FRONT:
										num = point.Y - num5;
										break;
									case Position.DepthEnum.BEHIND:
										num = point.Y + num5;
										break;
									}
								}
							}
							else if (isDistanceOnPositiveAxe)
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y - num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y + num5;
									break;
								}
							}
							else
							{
								switch (properties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y + num5;
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y - num5;
									break;
								}
							}
							p = new Point(0.0, num, 0.0);
							p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), num, 0.0);
						}
					}
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
					Point point2 = new Point(currentTransformationPlane.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(p)));
					Point point3 = new Point(currentTransformationPlane.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(p2)));
					LineSegment item = new LineSegment(point2, point3);
					list.Add(item);
				}
			}
			return PlateBeamConverterTools.CalculateContourPoints(list);
		}

		// Token: 0x060000C8 RID: 200 RVA: 0x00008BB0 File Offset: 0x00006DB0
		private static ArrayList CalculatePointsForUCMLProfiles(OriginalPolyBeamProperties originalBeamProperties, bool isDistanceOnPositiveAxe, bool isWebPlate, bool isSecondWebPlate)
		{
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			double num = 0.0;
			double num2 = originalBeamProperties.PolyBeamHeight;
			double polyBeamHeight = originalBeamProperties.PolyBeamHeight1;
			double polyBeamHeight2 = originalBeamProperties.PolyBeamHeight2;
			if (num2 == 0.0)
			{
				num2 = PlateBeamConverterTools.IdentifyTheBiggerValue(polyBeamHeight, polyBeamHeight2);
			}
			double num3 = num2 / 2.0;
			double num4 = originalBeamProperties.PolyBeamFlangeThickness;
			double num5 = originalBeamProperties.PolyBeamWidth;
			double num6 = originalBeamProperties.PolyBeamWebThickness;
			if (isWebPlate)
			{
				if (num6 == 0.0)
				{
					num6 = originalBeamProperties.PolyBeamPlateFlangeThickness;
					if (num6 == 0.0)
					{
						num6 = originalBeamProperties.PolyBeamFlangeThickness1;
					}
				}
				if (num4 == 0.0)
				{
					num4 = originalBeamProperties.PolyBeamPlateFlangeThickness;
					if (num4 == 0.0)
					{
						num4 = originalBeamProperties.PolyBeamFlangeThickness1;
					}
				}
				if (num5 == 0.0)
				{
					num5 = originalBeamProperties.PolyBeamHeight;
				}
			}
			else
			{
				if (num4 == 0.0)
				{
					num4 = originalBeamProperties.PolyBeamPlateFlangeThickness;
					if (num4 == 0.0)
					{
						num4 = originalBeamProperties.PolyBeamFlangeThickness1;
					}
				}
				if (num5 == 0.0)
				{
					num5 = originalBeamProperties.PolyBeamHeight;
				}
			}
			double num7 = num5 / 2.0;
			double num8 = num6 / 2.0;
			double num9;
			if (PlateBeamConverterTools.IsProfileWebAndFlangeThicknessAreTheSame(originalBeamProperties))
			{
				num9 = num3 - num6;
			}
			else
			{
				num9 = num3 - num4;
			}
			List<LineSegment> list = new List<LineSegment>();
			for (int i = 0; i < originalBeamProperties.PolyBeamSegmentCoordinateSystems.Count; i++)
			{
				CoordinateSystem coordinateSystem = originalBeamProperties.PolyBeamSegmentCoordinateSystems[i] as CoordinateSystem;
				if (coordinateSystem != null)
				{
					TransformationPlane transformationPlane = new TransformationPlane(coordinateSystem);
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(transformationPlane);
					CoordinateSystem polyBeamCoordinateSystem = originalBeamProperties.PolyBeamCoordinateSystem;
					TransformationPlane transformationPlane2 = new TransformationPlane(polyBeamCoordinateSystem);
					Point point = new Point(transformationPlane2.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(polyBeamCoordinateSystem.Origin)));
					Point p = new Point();
					Point p2 = new Point();
					double num10 = 0.0;
					if (originalBeamProperties.PolyBeamPosition.Rotation == Position.RotationEnum.TOP || originalBeamProperties.PolyBeamPosition.Rotation == Position.RotationEnum.BELOW)
					{
						if (originalBeamProperties.PolyBeamPosition.Rotation != Position.RotationEnum.TOP)
						{
							if (!isDistanceOnPositiveAxe)
							{
								switch (originalBeamProperties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y + num9;
									if (!isSecondWebPlate)
									{
										num10 = -num7 + num8;
									}
									else
									{
										num10 = num7 - num8;
									}
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y - num9;
									if (!isSecondWebPlate)
									{
										num10 = num7 - num8;
									}
									else
									{
										num10 = -num7 + num8;
									}
									break;
								}
							}
							else
							{
								switch (originalBeamProperties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Y - num9;
									if (!isSecondWebPlate)
									{
										num10 = -num7 + num8;
									}
									else
									{
										num10 = num7 - num8;
									}
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Y + num9;
									if (!isSecondWebPlate)
									{
										num10 = num7 - num8;
									}
									else
									{
										num10 = -num7 + num8;
									}
									break;
								}
							}
						}
						else if (!isDistanceOnPositiveAxe)
						{
							switch (originalBeamProperties.PolyBeamPosition.Depth)
							{
							case Position.DepthEnum.FRONT:
								num = point.Y - num9;
								if (!isSecondWebPlate)
								{
									num10 = num7 - num8;
								}
								else
								{
									num10 = -num7 + num8;
								}
								break;
							case Position.DepthEnum.BEHIND:
								num = point.Y + num9;
								if (!isSecondWebPlate)
								{
									num10 = -num7 + num8;
								}
								else
								{
									num10 = num7 - num8;
								}
								break;
							}
						}
						else
						{
							switch (originalBeamProperties.PolyBeamPosition.Depth)
							{
							case Position.DepthEnum.FRONT:
								num = point.Y + num9;
								if (!isSecondWebPlate)
								{
									num10 = num7 - num8;
								}
								else
								{
									num10 = -num7 + num8;
								}
								break;
							case Position.DepthEnum.BEHIND:
								num = point.Y - num9;
								if (!isSecondWebPlate)
								{
									num10 = -num7 + num8;
								}
								else
								{
									num10 = num7 - num8;
								}
								break;
							}
						}
						p = new Point(0.0, num, num10);
						p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), num, num10);
					}
					else if (originalBeamProperties.PolyBeamPosition.Rotation == Position.RotationEnum.FRONT || originalBeamProperties.PolyBeamPosition.Rotation == Position.RotationEnum.BACK)
					{
						if (originalBeamProperties.PolyBeamPosition.Rotation != Position.RotationEnum.FRONT)
						{
							if (!isDistanceOnPositiveAxe)
							{
								switch (originalBeamProperties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Z - num9;
									if (!isSecondWebPlate)
									{
										num10 = -num7 - num8;
									}
									else
									{
										num10 = num7 - num8;
									}
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Z + num9;
									if (!isSecondWebPlate)
									{
										num10 = num7 - num8;
									}
									else
									{
										num10 = -num7 + num8;
									}
									break;
								}
							}
							else
							{
								switch (originalBeamProperties.PolyBeamPosition.Depth)
								{
								case Position.DepthEnum.FRONT:
									num = point.Z + num9;
									if (!isSecondWebPlate)
									{
										num10 = -num7 + num8;
									}
									else
									{
										num10 = num7 - num8;
									}
									break;
								case Position.DepthEnum.BEHIND:
									num = point.Z - num9;
									if (!isSecondWebPlate)
									{
										num10 = num7 - num8;
									}
									else
									{
										num10 = -num7 + num8;
									}
									break;
								}
							}
						}
						else if (!isDistanceOnPositiveAxe)
						{
							switch (originalBeamProperties.PolyBeamPosition.Depth)
							{
							case Position.DepthEnum.FRONT:
								num = point.Z + num9;
								if (!isSecondWebPlate)
								{
									num10 = num7 - num8;
								}
								else
								{
									num10 = -num7 + num8;
								}
								break;
							case Position.DepthEnum.BEHIND:
								num = point.Z - num9;
								if (!isSecondWebPlate)
								{
									num10 = -num7 + num8;
								}
								else
								{
									num10 = num7 - num8;
								}
								break;
							}
						}
						else
						{
							switch (originalBeamProperties.PolyBeamPosition.Depth)
							{
							case Position.DepthEnum.FRONT:
								num = point.Z - num9;
								if (!isSecondWebPlate)
								{
									num10 = num7 - num8;
								}
								else
								{
									num10 = -num7 + num8;
								}
								break;
							case Position.DepthEnum.BEHIND:
								num = point.Z + num9;
								if (!isSecondWebPlate)
								{
									num10 = -num7 + num8;
								}
								else
								{
									num10 = num7 - num8;
								}
								break;
							}
						}
						p = new Point(0.0, num10, num);
						p2 = new Point(PlateBeamConverterTools.BeamLength(coordinateSystem), num10, num);
					}
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
					Point point2 = new Point(currentTransformationPlane.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(p)));
					Point point3 = new Point(currentTransformationPlane.TransformationMatrixToLocal.Transform(transformationPlane.TransformationMatrixToGlobal.Transform(p2)));
					LineSegment item = new LineSegment(point2, point3);
					list.Add(item);
				}
			}
			return PlateBeamConverterTools.CalculateContourPoints(list);
		}

		// Token: 0x060000C9 RID: 201 RVA: 0x000093C8 File Offset: 0x000075C8
		private static void CalculatePosition(OriginalBeamProperties originalBeamProperties, double beamLength, Beam webPlate, double halfOfBeamHeight, bool isSecondWebPlate)
		{
			double num = originalBeamProperties.BeamWidth;
			if (num == 0.0)
			{
				num = originalBeamProperties.BeamHeight;
			}
			if (isSecondWebPlate)
			{
				if (originalBeamProperties.BeamFlangeThickness == 0.0 && originalBeamProperties.BeamWebThickness == 0.0)
				{
					double num2 = originalBeamProperties.BeamPlateFlangeThickness;
					if (num2 == 0.0)
					{
						num2 = originalBeamProperties.BeamFlangeThickness1;
					}
					double y = -halfOfBeamHeight + num2;
					double num3 = num / 2.0 - num2 / 2.0;
					webPlate.StartPoint = new Point(0.0, y, -num3);
					webPlate.EndPoint = new Point(beamLength, y, -num3);
				}
				else
				{
					double y = -halfOfBeamHeight + originalBeamProperties.BeamFlangeThickness;
					double num4 = num / 2.0 - originalBeamProperties.BeamWebThickness / 2.0;
					webPlate.StartPoint = new Point(0.0, y, -num4);
					webPlate.EndPoint = new Point(beamLength, y, -num4);
				}
			}
			else if (originalBeamProperties.BeamFlangeThickness == 0.0 && originalBeamProperties.BeamWebThickness == 0.0)
			{
				double beamPlateFlangeThickness = originalBeamProperties.BeamPlateFlangeThickness;
				double y = -halfOfBeamHeight + beamPlateFlangeThickness;
				double z = num / 2.0 - beamPlateFlangeThickness / 2.0;
				webPlate.StartPoint = new Point(0.0, y, z);
				webPlate.EndPoint = new Point(beamLength, y, z);
			}
			else
			{
				double y = -halfOfBeamHeight + originalBeamProperties.BeamFlangeThickness;
				double z2 = num / 2.0 - originalBeamProperties.BeamWebThickness / 2.0;
				webPlate.StartPoint = new Point(0.0, y, z2);
				webPlate.EndPoint = new Point(beamLength, y, z2);
			}
		}

		// Token: 0x060000CA RID: 202 RVA: 0x000095E4 File Offset: 0x000077E4
		private static void CalculateUpperFlangePlateStartAndEndPoint(OriginalBeamProperties originalBeamProperties, double beamLength, Beam upperFlangePlate, double halfBeamHeight, double flangeLocation, double beamHeight)
		{
			if (PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties))
			{
				double y = beamHeight - originalBeamProperties.BeamHeight2 / 2.0;
				double y2 = originalBeamProperties.BeamHeight2 / 2.0;
				upperFlangePlate.StartPoint = new Point(0.0, y, 0.0);
				upperFlangePlate.EndPoint = new Point(beamLength, y2, 0.0);
			}
			else
			{
				upperFlangePlate.StartPoint = new Point(0.0, flangeLocation, 0.0);
				upperFlangePlate.EndPoint = new Point(beamLength, halfBeamHeight, 0.0);
			}
		}

		// Token: 0x060000CB RID: 203 RVA: 0x0000969C File Offset: 0x0000789C
		private static void CalculateUpperFlangePlateStartAndEndPoint(OriginalPolyBeamProperties originalBeamProperties, double beamLength, Beam upperFlangePlate, double halfBeamHeight, double flangeLocation, double beamHeight)
		{
			if (PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties))
			{
				double y = beamHeight - originalBeamProperties.PolyBeamHeight2 / 2.0;
				double y2 = originalBeamProperties.PolyBeamHeight2 / 2.0;
				upperFlangePlate.StartPoint = new Point(0.0, y, 0.0);
				upperFlangePlate.EndPoint = new Point(beamLength, y2, 0.0);
			}
			else
			{
				upperFlangePlate.StartPoint = new Point(0.0, flangeLocation, 0.0);
				upperFlangePlate.EndPoint = new Point(beamLength, halfBeamHeight, 0.0);
			}
		}

		// Token: 0x060000CC RID: 204 RVA: 0x00009754 File Offset: 0x00007954
		private static void CalculateWebPlateStartAndEndPoint(OriginalBeamProperties originalBeamProperties, double beamLength, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType, double beamHeight, Beam webPlate, bool isSecondWebPlate)
		{
			double num = beamHeight / 2.0;
			double num2 = originalBeamProperties.BeamHeight2 / 2.0;
			double y = -num2 + originalBeamProperties.BeamFlangeThickness;
			double y2 = -num2 + originalBeamProperties.BeamFlangeThickness2;
			if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				if (subType == PlateBeamConverterTools.ProfileISubTypes.Tapered && PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties))
				{
					webPlate.StartPoint = new Point(0.0, y, 0.0);
					webPlate.EndPoint = new Point(beamLength, y, 0.0);
				}
				else if (subType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
				{
					webPlate.StartPoint = new Point(0.0, y2, 0.0);
					webPlate.EndPoint = new Point(beamLength, y2, 0.0);
				}
				else
				{
					double y3 = -num + originalBeamProperties.BeamFlangeThickness;
					webPlate.StartPoint = new Point(0.0, y3, 0.0);
					webPlate.EndPoint = new Point(beamLength, y3, 0.0);
				}
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT)
			{
				double y3 = -num;
				webPlate.StartPoint = new Point(0.0, y3, 0.0);
				webPlate.EndPoint = new Point(beamLength, y3, 0.0);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileCorU)
			{
				PlateBeamConverterTools.CalculatePosition(originalBeamProperties, beamLength, webPlate, num, true);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection)
			{
				if (isSecondWebPlate)
				{
					PlateBeamConverterTools.CalculatePosition(originalBeamProperties, beamLength, webPlate, num, true);
				}
				else
				{
					PlateBeamConverterTools.CalculatePosition(originalBeamProperties, beamLength, webPlate, num, false);
				}
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileAngle)
			{
				PlateBeamConverterTools.CalculatePosition(originalBeamProperties, beamLength, webPlate, num, true);
			}
		}

		// Token: 0x060000CD RID: 205 RVA: 0x00009964 File Offset: 0x00007B64
		public static bool CreateBuiltUpSectionPlatesMainMethod(Beam selectedBeam, string platesPrefix, string assemblePrefix, string weldsAttributeFileName)
		{
			bool flag = false;
			bool result;
			if (selectedBeam != null && selectedBeam.Identifier.ID != 0)
			{
				if (PlateBeamConverterTools.IsSelectedPartProfileOneOfTheSupporterdProfiles(selectedBeam))
				{
					TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
					flag = PlateBeamConverterTools.CreateSupportedProfilePlateBeams(selectedBeam, platesPrefix, assemblePrefix, weldsAttributeFileName);
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
					PlateBeamConverterTools.WorkingModel.CommitChanges();
					result = flag;
					return result;
				}
				string text = LocalizationTools.Localization.GetText("选择零件的ID");
				string text2 = LocalizationTools.Localization.GetText("零件不是I、U、C、M、L或T型截面");
				Utility.MessageList.Add(text + selectedBeam.Identifier.ID + text2);
			}
			result = flag;
			return result;
		}

		// Token: 0x060000CE RID: 206 RVA: 0x00009A28 File Offset: 0x00007C28
		public static bool CreateBuiltUpSectionPlatesMainMethod(PolyBeam selectedPolyBeam, string platesPrefix, string weldsAttributeFileName)
		{
			bool flag = false;
			bool result;
			if (selectedPolyBeam != null && selectedPolyBeam.Identifier.ID != 0)
			{
				if (PlateBeamConverterTools.IsSelectedPartProfileOneOfTheSupporterdProfiles(selectedPolyBeam))
				{
					TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
					flag = PlateBeamConverterTools.CreateSupportedProfilePlatePolyBeams(selectedPolyBeam, platesPrefix, weldsAttributeFileName);
					PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
					PlateBeamConverterTools.WorkingModel.CommitChanges();
					result = flag;
					return result;
				}
				string text = LocalizationTools.Localization.GetText("albl_Selected_part_with_ID");
				string text2 = LocalizationTools.Localization.GetText("albl_is_not_I_U_C_M_L_or_T_profile_type");
				Utility.MessageList.Add(text + selectedPolyBeam.Identifier.ID + text2);
			}
			result = flag;
			return result;
		}

		// Token: 0x060000CF RID: 207 RVA: 0x00009AEC File Offset: 0x00007CEC
		private static void CreateCutPlaneForTaperedBeam(OriginalBeamProperties originalBeamProperties, PlateBeamConverterTools.ProfileISubTypes profileSubType, double beamLength, Beam webPlate, Beam upperFlenge)
		{
			if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.Tapered || profileSubType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
			{
				Vector axesX;
				Point originPoint = PlateBeamConverterTools.CutPlaneOriginPointAndVectorX(originalBeamProperties, beamLength, upperFlenge, profileSubType, out axesX);
				PlateBeamConverterTools.InsertCutPlaneForTaperedBeamCut(webPlate, axesX, originPoint);
			}
		}

		// Token: 0x060000D0 RID: 208 RVA: 0x00009B28 File Offset: 0x00007D28
		private static void CreateCutPlaneForTaperedBeam(OriginalPolyBeamProperties originalBeamProperties, PlateBeamConverterTools.ProfileISubTypes profileSubType, double beamLength, Beam webPlate, Beam upperFlenge)
		{
			if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.Tapered || profileSubType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
			{
				Vector axesX;
				Point originPoint = PlateBeamConverterTools.CutPlaneOriginPointAndVectorX(originalBeamProperties, beamLength, upperFlenge, profileSubType, out axesX);
				PlateBeamConverterTools.InsertCutPlaneForTaperedBeamCut(webPlate, axesX, originPoint);
			}
		}

		// Token: 0x060000D1 RID: 209 RVA: 0x00009B64 File Offset: 0x00007D64
		private static PolyBeam CreateLowerFlangePlate(string platesPrefix, OriginalPolyBeamProperties originalPolyBeamProperties, PlateBeamConverterTools.ProfileTypes profileType)
		{
			PolyBeam polyBeam = PlateBeamConverterTools.TheUpperFlenge(platesPrefix, originalPolyBeamProperties);
			ArrayList contourPoints = PlateBeamConverterTools.CalculatePointsForITProfiles(originalPolyBeamProperties, profileType, true, false, false);
			polyBeam.Contour.ContourPoints = contourPoints;
			polyBeam.Name = "下翼缘";
			polyBeam.Position.Plane = Position.PlaneEnum.RIGHT;
			polyBeam.Position.Depth = Position.DepthEnum.MIDDLE;
			polyBeam.Position.Rotation = Position.RotationEnum.BELOW;
			return polyBeam;
		}

		// Token: 0x060000D2 RID: 210 RVA: 0x00009BCC File Offset: 0x00007DCC
		private static Beam CreateLowerFlangePlate(string platesPrefix, string assemblePrefix, OriginalBeamProperties originalBeamProperties, double beamLength, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType)
		{
			double theBeamHeight = PlateBeamConverterTools.GetTheBeamHeight(originalBeamProperties, subType);
			Beam beam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalBeamProperties, platesPrefix, assemblePrefix);
			beam.Profile.ProfileString = PlateBeamConverterTools.GetFlangeProfile(originalBeamProperties, subType, false);
			PlateBeamConverterTools.CalculateLowerFlangePlateStartAndEndPoint(originalBeamProperties, beamLength, profileType, subType, theBeamHeight, beam);
			beam.Position.Plane = Position.PlaneEnum.LEFT;
			beam.Position.Depth = Position.DepthEnum.MIDDLE;
			beam.Position.Rotation = Position.RotationEnum.BELOW;
			beam.Name = "下翼缘";
			return beam;
		}

		// Token: 0x060000D3 RID: 211 RVA: 0x00009C48 File Offset: 0x00007E48
		private static bool CreatePlateBeams(string platesPrefix, string assemblePrefix, OriginalBeamProperties originalBeamProperties, CoordinateSystem plateBeamsGeneralCoordinateSystem, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes profileSubType, ref List<ModelObject> modelObjects)
		{
			TransformationPlane currentTransformationPlane = new TransformationPlane(plateBeamsGeneralCoordinateSystem);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
			double beamLength = PlateBeamConverterTools.BeamLength(plateBeamsGeneralCoordinateSystem);
			Beam beam = new Beam();
			Beam beam2 = new Beam();
			Beam beam3 = new Beam();
			Beam beam4 = new Beam();
			bool flag = false;
			switch (profileType)
			{
			case PlateBeamConverterTools.ProfileTypes.ProfileI:
			case PlateBeamConverterTools.ProfileTypes.ProfileCorU:
				beam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				beam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType, false);
				beam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				flag = (beam3.Insert() && beam.Insert() && beam2.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileT:
				beam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				beam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType, false);
				flag = (beam3.Insert() && beam.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection:
				beam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				beam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType, false);
				beam4 = PlateBeamConverterTools.CreateWebPlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType, true);
				beam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				flag = (beam3.Insert() && beam.Insert() && beam4.Insert() && beam2.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileAngle:
				beam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType);
				beam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, assemblePrefix, originalBeamProperties, beamLength, profileType, profileSubType, false);
				flag = (beam.Insert() && beam2.Insert());
				break;
			}
			bool result;
			if (flag)
			{
				if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileI)
				{
					PlateBeamConverterTools.CreateCutPlaneForTaperedBeam(originalBeamProperties, profileSubType, beamLength, beam, beam3);
				}
				PlateBeamConverterTools.AddCreatedPlateBeamsToList(profileType, modelObjects, beam3, beam, beam4, beam2);
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("用板创建梁的方法失败:板梁创建失败");
				Operation.DisplayPrompt(TeklaStructures.Environment.Localization.GetText("板梁创建失败"));
				result = flag;
			}
			return result;
		}

		// Token: 0x060000D4 RID: 212 RVA: 0x00009E48 File Offset: 0x00008048
		private static CoordinateSystem CreatePlateBeamsGeneralCoordinateSystem(CoordinateSystem originalBeamCoordinateSystem)
		{
			return PlateBeamConverterTools.PlateBeamsGeneralCoordinateSystem(originalBeamCoordinateSystem);
		}

		// Token: 0x060000D5 RID: 213 RVA: 0x00009E60 File Offset: 0x00008060
		private static Beam CreatePlateWithCommonProperties(OriginalBeamProperties properties, string platePrefix, string assemblePrefix)
		{
			Beam beam = new Beam
			{
				Material = properties.BeamMaterial,
				Finish = properties.BeamFinish,
				Class = properties.BeamClass
			};
			beam.PartNumber.Prefix = ((platePrefix == string.Empty) ? properties.BeamPrefix : platePrefix);
			beam.AssemblyNumber.Prefix = assemblePrefix;
			return beam;
		}

		// Token: 0x060000D6 RID: 214 RVA: 0x00009ED8 File Offset: 0x000080D8
		private static PolyBeam CreatePlateWithCommonProperties(OriginalPolyBeamProperties properties, string platePrefix)
		{
			PolyBeam polyBeam = new PolyBeam
			{
				Material = properties.PolyBeamMaterial,
				Finish = properties.PolyBeamFinish,
				Class = properties.PolyBeamClass
			};
			polyBeam.PartNumber.Prefix = ((platePrefix == string.Empty) ? properties.PolyBeamPrefix : platePrefix);
			return polyBeam;
		}

		// Token: 0x060000D7 RID: 215 RVA: 0x00009F44 File Offset: 0x00008144
		private static bool CreatePolyBeamsFromPlates(string platesPrefix, OriginalPolyBeamProperties originalPolyBeamProperties, CoordinateSystem plateBeamsGeneralCoordinateSystem, PlateBeamConverterTools.ProfileTypes profileType, ref List<ModelObject> modelObjects)
		{
			TransformationPlane currentTransformationPlane = new TransformationPlane(plateBeamsGeneralCoordinateSystem);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
			PolyBeam polyBeam = new PolyBeam();
			PolyBeam polyBeam2 = new PolyBeam();
			PolyBeam polyBeam3 = new PolyBeam();
			PolyBeam polyBeam4 = new PolyBeam();
			bool flag = false;
			switch (profileType)
			{
			case PlateBeamConverterTools.ProfileTypes.ProfileI:
			case PlateBeamConverterTools.ProfileTypes.ProfileCorU:
				polyBeam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				polyBeam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, originalPolyBeamProperties, profileType, false);
				polyBeam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				flag = (polyBeam2.Insert() && polyBeam.Insert() && polyBeam3.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileT:
				polyBeam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				polyBeam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, originalPolyBeamProperties, profileType, false);
				flag = (polyBeam3.Insert() && polyBeam.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection:
				polyBeam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				polyBeam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, originalPolyBeamProperties, profileType, false);
				polyBeam4 = PlateBeamConverterTools.CreateWebPlate(platesPrefix, originalPolyBeamProperties, profileType, true);
				polyBeam3 = PlateBeamConverterTools.CreateUpperFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				flag = (polyBeam2.Insert() && polyBeam.Insert() && polyBeam4.Insert() && polyBeam3.Insert());
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileAngle:
				polyBeam2 = PlateBeamConverterTools.CreateLowerFlangePlate(platesPrefix, originalPolyBeamProperties, profileType);
				polyBeam = PlateBeamConverterTools.CreateWebPlate(platesPrefix, originalPolyBeamProperties, profileType, false);
				flag = (polyBeam2.Insert() && polyBeam.Insert());
				break;
			}
			bool result;
			if (flag)
			{
				PlateBeamConverterTools.AddCreatedPlateBeamsToList(profileType, modelObjects, polyBeam3, polyBeam, polyBeam4, polyBeam2);
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("CreatePolyBeamsFromPlates method fail: Plate poly beams creation failed");
				Operation.DisplayPrompt(TeklaStructures.Environment.Localization.GetText("albl_PlatePolyBeams_creation_failed"));
				result = flag;
			}
			return result;
		}

		// Token: 0x060000D8 RID: 216 RVA: 0x0000A0DC File Offset: 0x000082DC
		private static bool CreateSupportedProfilePlateBeams(Beam selectedBeam, string platesPrefix, string assemblePrefix, string weldsAttributeFileName)
		{
			OriginalBeamProperties originalBeamProperties = default(OriginalBeamProperties);
			List<ModelObject> list = new List<ModelObject>();
			CoordinateSystem originalBeamCoordinateSystem = new CoordinateSystem();
			List<Welds.WeldInformationStruct> weldInformationList = new List<Welds.WeldInformationStruct>();
			List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList = new List<Welds.PolygonWeldInformationStruct>();
			PlateBeamConverterTools.GetSelectedBeamPropertiesAndAssociativeObjectsInOriginalBeamsTransformationPlane(selectedBeam, ref originalBeamProperties, ref originalBeamCoordinateSystem);
			CoordinateSystem plateBeamsGeneralCoordinateSystem = PlateBeamConverterTools.CreatePlateBeamsGeneralCoordinateSystem(originalBeamCoordinateSystem);
			PlateBeamConverterTools.ProfileISubTypes profileSubType = PlateBeamConverterTools.IdentifyIPartSubtype(originalBeamProperties);
			PlateBeamConverterTools.ExplodeComponentsFromSelectedBeam(originalBeamProperties);
			PlateBeamConverterTools.GetAllWeldsFromSelectedBeamAndAddToInformationList(selectedBeam, ref weldInformationList, ref polygonWeldInformationList);
			PlateBeamConverterTools.ProfileTypes profileType = PlateBeamConverterTools.GetProfileType(selectedBeam);
			bool flag;
			bool result;
			if (flag = PlateBeamConverterTools.CreatePlateBeams(platesPrefix, assemblePrefix, originalBeamProperties, plateBeamsGeneralCoordinateSystem, profileType, profileSubType, ref list))
			{
				Welds.CreateWeldsBetweenWebAndFlangesMainMethod(profileType, list, weldsAttributeFileName);
				PlateBeamConverterTools.InsertAssociativeObjectsMainMethod(originalBeamProperties, list, plateBeamsGeneralCoordinateSystem);
				Welds.WeldsAndPolygonWeldsToPlateBeams(list, weldInformationList, polygonWeldInformationList, originalBeamProperties, plateBeamsGeneralCoordinateSystem, profileType);
				PlateBeamConverterTools.DeleteOriginalBeam(selectedBeam);
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("创建I型板梁方法失败: 板梁没有创建");
				Operation.DisplayPrompt(TeklaStructures.Environment.Localization.GetText("板梁创建失败"));
				result = flag;
			}
			return result;
		}

		// Token: 0x060000D9 RID: 217 RVA: 0x0000A1C0 File Offset: 0x000083C0
		private static bool CreateSupportedProfilePlatePolyBeams(PolyBeam selectedPolyBeam, string platesPrefix, string weldsAttributeFileName)
		{
			OriginalPolyBeamProperties originalPolyBeamProperties = default(OriginalPolyBeamProperties);
			List<ModelObject> list = new List<ModelObject>();
			CoordinateSystem originalBeamCoordinateSystem = new CoordinateSystem();
			List<Welds.WeldInformationStruct> weldInformationList = new List<Welds.WeldInformationStruct>();
			List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList = new List<Welds.PolygonWeldInformationStruct>();
			PlateBeamConverterTools.GetSelectedPolyBeamPropertiesAndAssociativeObjectsInOriginalBeamsTransformationPlane(selectedPolyBeam, ref originalPolyBeamProperties, ref originalBeamCoordinateSystem);
			CoordinateSystem plateBeamsGeneralCoordinateSystem = PlateBeamConverterTools.CreatePlateBeamsGeneralCoordinateSystem(originalBeamCoordinateSystem);
			PlateBeamConverterTools.ProfileTypes profileType = PlateBeamConverterTools.GetProfileType(selectedPolyBeam);
			PlateBeamConverterTools.ExplodeComponentsFromSelectedBeam(originalPolyBeamProperties);
			PlateBeamConverterTools.GetAllWeldsFromSelectedPolyBeamAndAddToInformationList(selectedPolyBeam, ref weldInformationList, ref polygonWeldInformationList);
			bool flag = false;
			if (originalPolyBeamProperties.PolyBeamPosition.Depth != Position.DepthEnum.MIDDLE)
			{
				flag = PlateBeamConverterTools.CreatePolyBeamsFromPlates(platesPrefix, originalPolyBeamProperties, plateBeamsGeneralCoordinateSystem, profileType, ref list);
			}
			else
			{
				Utility.MessageList.Add("If poly beam position on depth is set Middle, creation is not supported");
			}
			bool result;
			if (flag)
			{
				Welds.CreateWeldsBetweenWebAndFlangesMainMethod(profileType, list, weldsAttributeFileName);
				PlateBeamConverterTools.InsertAssociativeObjectsMainMethod(originalPolyBeamProperties, list, plateBeamsGeneralCoordinateSystem);
				Welds.WeldsAndPolygonWeldsToPlateBeams(list, weldInformationList, polygonWeldInformationList, originalPolyBeamProperties, plateBeamsGeneralCoordinateSystem, profileType);
				PlateBeamConverterTools.DeleteOriginalPolyBeam(selectedPolyBeam);
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("CreateProfileIPlatePolyBeams method fail: Plate poly beams not created");
				Operation.DisplayPrompt(TeklaStructures.Environment.Localization.GetText("albl_PlateBeams_creation_failed"));
				result = flag;
			}
			return result;
		}

		// Token: 0x060000DA RID: 218 RVA: 0x0000A2C8 File Offset: 0x000084C8
		private static PolyBeam CreateUpperFlangePlate(string platesPrefix, OriginalPolyBeamProperties originalPolyBeamProperties, PlateBeamConverterTools.ProfileTypes profileTypes)
		{
			PolyBeam polyBeam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalPolyBeamProperties, platesPrefix);
			polyBeam.Profile.ProfileString = PlateBeamConverterTools.GetFlangeProfile(originalPolyBeamProperties, false);
			ArrayList contourPoints = PlateBeamConverterTools.CalculatePointsForITProfiles(originalPolyBeamProperties, profileTypes, false, false, true);
			polyBeam.Contour.ContourPoints = contourPoints;
			polyBeam.Position.Plane = Position.PlaneEnum.LEFT;
			polyBeam.Position.Depth = Position.DepthEnum.MIDDLE;
			polyBeam.Position.Rotation = Position.RotationEnum.BELOW;
			polyBeam.Name = "Upper Flange";
			return polyBeam;
		}

		// Token: 0x060000DB RID: 219 RVA: 0x0000A344 File Offset: 0x00008544
		private static Beam CreateUpperFlangePlate(string platesPrefix, string assemblePrefix, OriginalBeamProperties originalBeamProperties, double beamLength, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType)
		{
			Beam beam = PlateBeamConverterTools.TheUpperFlenge(platesPrefix, assemblePrefix, originalBeamProperties, profileType, subType);
			Beam result;
			switch (subType)
			{
			case PlateBeamConverterTools.ProfileISubTypes.Normal:
				PlateBeamConverterTools.NormalFlangeOrientation(originalBeamProperties, beamLength, beam);
				result = beam;
				break;
			case PlateBeamConverterTools.ProfileISubTypes.Tapered:
				PlateBeamConverterTools.TaperedFlangeOrientation(originalBeamProperties, beamLength, beam);
				result = beam;
				break;
			case PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges:
				PlateBeamConverterTools.TaperedFlangeOrientation(originalBeamProperties, beamLength, beam);
				result = beam;
				break;
			default:
				result = beam;
				break;
			}
			return result;
		}

		// Token: 0x060000DC RID: 220 RVA: 0x0000A3A4 File Offset: 0x000085A4
		private static PolyBeam CreateWebPlate(string platesPrefix, OriginalPolyBeamProperties originalPolyBeamProperties, PlateBeamConverterTools.ProfileTypes profileType, bool isSecondWebPlate)
		{
			PolyBeam polyBeam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalPolyBeamProperties, platesPrefix);
			polyBeam.Profile.ProfileString = PlateBeamConverterTools.GetWebProfile(originalPolyBeamProperties, profileType);
			ArrayList contourPoints = new ArrayList();
			if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				contourPoints = PlateBeamConverterTools.CalculatePointsForITProfiles(originalPolyBeamProperties, profileType, true, false, false);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT)
			{
				contourPoints = PlateBeamConverterTools.CalculatePointsForITProfiles(originalPolyBeamProperties, profileType, true, true, false);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileCorU)
			{
				contourPoints = PlateBeamConverterTools.CalculatePointsForUCMLProfiles(originalPolyBeamProperties, true, true, false);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileAngle)
			{
				contourPoints = PlateBeamConverterTools.CalculatePointsForUCMLProfiles(originalPolyBeamProperties, true, true, false);
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection)
			{
				contourPoints = PlateBeamConverterTools.CalculatePointsForUCMLProfiles(originalPolyBeamProperties, true, true, isSecondWebPlate);
			}
			polyBeam.Contour.ContourPoints = contourPoints;
			polyBeam.Position.Plane = Position.PlaneEnum.LEFT;
			polyBeam.Position.Depth = Position.DepthEnum.MIDDLE;
			polyBeam.Position.Rotation = Position.RotationEnum.FRONT;
			polyBeam.Name = "腹板";
			return polyBeam;
		}

		// Token: 0x060000DD RID: 221 RVA: 0x0000A498 File Offset: 0x00008698
		private static Beam CreateWebPlate(string platesPrefix, string assemblePrefix, OriginalBeamProperties originalBeamProperties, double beamLength, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType, bool secondWebPlate)
		{
			double theBeamHeight = PlateBeamConverterTools.GetTheBeamHeight(originalBeamProperties, subType);
			Beam beam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalBeamProperties, platesPrefix, assemblePrefix);
			beam.Profile.ProfileString = PlateBeamConverterTools.GetWebProfile(originalBeamProperties, profileType, subType);
			PlateBeamConverterTools.CalculateWebPlateStartAndEndPoint(originalBeamProperties, beamLength, profileType, subType, theBeamHeight, beam, secondWebPlate);
			beam.Position.Plane = Position.PlaneEnum.LEFT;
			beam.Position.Depth = Position.DepthEnum.MIDDLE;
			beam.Position.Rotation = Position.RotationEnum.FRONT;
			beam.Name = "腹板";
			return beam;
		}

		// Token: 0x060000DE RID: 222 RVA: 0x0000A518 File Offset: 0x00008718
		private static Point CutPlaneOriginPointAndVectorX(OriginalBeamProperties originalBeamProperties, double beamLength, Beam upperFlange, PlateBeamConverterTools.ProfileISubTypes profileSubType, out Vector directionXVector)
		{
			double beamHeight = originalBeamProperties.BeamHeight1;
			double beamHeight2 = originalBeamProperties.BeamHeight2;
			double halfBeamHeight = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2) / 2.0;
			double beamFlangeThickness = originalBeamProperties.BeamFlangeThickness1;
			double beamFlangeThickness2 = originalBeamProperties.BeamFlangeThickness2;
			Point result = new Point();
			LineSegment lineSegment = new LineSegment();
			if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.Tapered)
			{
				result = PlateBeamConverterTools.GetOriginPoint(originalBeamProperties, beamLength, upperFlange, halfBeamHeight, beamFlangeThickness2, beamFlangeThickness, out lineSegment);
			}
			else if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
			{
				result = PlateBeamConverterTools.GetTheOriginPoint(upperFlange, beamFlangeThickness, beamFlangeThickness2, out lineSegment);
			}
			directionXVector = lineSegment.GetDirectionVector();
			return result;
		}

		// Token: 0x060000DF RID: 223 RVA: 0x0000A5B8 File Offset: 0x000087B8
		private static Point CutPlaneOriginPointAndVectorX(OriginalPolyBeamProperties originalBeamProperties, double beamLength, Beam upperFlange, PlateBeamConverterTools.ProfileISubTypes profileSubType, out Vector directionXVector)
		{
			double polyBeamHeight = originalBeamProperties.PolyBeamHeight1;
			double polyBeamHeight2 = originalBeamProperties.PolyBeamHeight2;
			double halfBeamHeight = PlateBeamConverterTools.IdentifyTheBiggerValue(polyBeamHeight, polyBeamHeight2) / 2.0;
			double polyBeamFlangeThickness = originalBeamProperties.PolyBeamFlangeThickness1;
			double polyBeamFlangeThickness2 = originalBeamProperties.PolyBeamFlangeThickness2;
			Point result = new Point();
			LineSegment lineSegment = new LineSegment();
			if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.Tapered)
			{
				result = PlateBeamConverterTools.GetOriginPoint(originalBeamProperties, beamLength, upperFlange, halfBeamHeight, polyBeamFlangeThickness2, polyBeamFlangeThickness, out lineSegment);
			}
			else if (profileSubType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
			{
				result = PlateBeamConverterTools.GetTheOriginPoint(upperFlange, polyBeamFlangeThickness, polyBeamFlangeThickness2, out lineSegment);
			}
			directionXVector = lineSegment.GetDirectionVector();
			return result;
		}

		// Token: 0x060000E0 RID: 224 RVA: 0x0000A658 File Offset: 0x00008858
		private static void DeleteOriginalBeam(Beam selectedBeam)
		{
			if (!selectedBeam.Delete())
			{
				Utility.MessageList.Add("DeleteOriginalBeam method fail: Original beam not deleted");
				Attributes.ShowMessage(TeklaStructures.Environment.Localization.GetText("albl_Original_beam_not_deleted"));
			}
		}

		// Token: 0x060000E1 RID: 225 RVA: 0x0000A658 File Offset: 0x00008858
		private static void DeleteOriginalPolyBeam(PolyBeam selectedPolyBeam)
		{
			if (!selectedPolyBeam.Delete())
			{
				Utility.MessageList.Add("DeleteOriginalBeam method fail: Original beam not deleted");
				Attributes.ShowMessage(TeklaStructures.Environment.Localization.GetText("albl_Original_beam_not_deleted"));
			}
		}

		// Token: 0x060000E2 RID: 226 RVA: 0x0000A69C File Offset: 0x0000889C
		public static void EliminateDuplicatesAndNotBeamsOrPolyBeams(ModelObjectEnumerator selectedPartsEnumIn, ref List<ModelObject> verifiedPartsListOut)
		{
			List<ModelObject> list = new List<ModelObject>();
			List<string> list2 = new List<string>();
			selectedPartsEnumIn.Reset();
			while (selectedPartsEnumIn.MoveNext())
			{
				ModelObject current = selectedPartsEnumIn.Current;
				if (current != null)
				{
					string item = current.Identifier.GUID.ToString();
					if (!list2.Contains(item) && current is Beam)
					{
						list.Add(current);
						list2.Add(item);
					}
				}
			}
			verifiedPartsListOut = list;
		}

		// Token: 0x060000E3 RID: 227 RVA: 0x0000A730 File Offset: 0x00008930
		private static void ExplodeComponentsFromSelectedBeam(OriginalBeamProperties originalBeamProperties)
		{
			List<ModelObject> components = originalBeamProperties.Components;
			if (components.Count > 0)
			{
				foreach (ModelObject current in components)
				{
					PlateBeamConverterTools.RunExplodeComponentMacro(current);
				}
			}
		}

		// Token: 0x060000E4 RID: 228 RVA: 0x0000A7A0 File Offset: 0x000089A0
		private static void ExplodeComponentsFromSelectedBeam(OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			List<ModelObject> components = originalPolyBeamProperties.Components;
			if (components.Count > 0)
			{
				foreach (ModelObject current in components)
				{
					PlateBeamConverterTools.RunExplodeComponentMacro(current);
				}
			}
		}

		// Token: 0x060000E5 RID: 229 RVA: 0x0000A810 File Offset: 0x00008A10
		private static void ExplodeSelectedComponent()
		{
			MacroBuilder macroBuilder = new MacroBuilder();
			macroBuilder.Callback("acmd_explode_selected_joints", string.Empty, "main_frame");
			macroBuilder.Run();
			PlateBeamConverterTools.WaitForMacro(10);
		}

		// Token: 0x060000E6 RID: 230 RVA: 0x0000A84C File Offset: 0x00008A4C
		private static void GetAllWeldsFromSelectedBeamAndAddToInformationList(Beam selectedBeam, ref List<Welds.WeldInformationStruct> weldInformationList, ref List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList)
		{
			selectedBeam.Select();
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			TransformationPlane currentTransformationPlane2 = new TransformationPlane(selectedBeam.GetCoordinateSystem());
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane2);
			ModelObjectEnumerator welds = selectedBeam.GetWelds();
			if (welds.GetSize() > 0)
			{
				while (welds.MoveNext())
				{
					if (welds.Current is Weld)
					{
						Weld weld = welds.Current as Weld;
						Welds.WeldInformationStruct item = new Welds.WeldInformationStruct
						{
							Weld = weld,
							MainObject = weld.MainObject,
							SecondaryObject = weld.SecondaryObject,
							WeldPositionEnum = weld.Position,
							WeldCoordinateSystem = weld.GetCoordinateSystem()
						};
						weldInformationList.Add(item);
					}
					else if (welds.Current is PolygonWeld)
					{
						PolygonWeld polygonWeld = welds.Current as PolygonWeld;
						Welds.PolygonWeldInformationStruct item2 = new Welds.PolygonWeldInformationStruct
						{
							PolygonWeld = polygonWeld,
							MainObject = polygonWeld.MainObject,
							SecondaryObject = polygonWeld.SecondaryObject,
							PolygonWeldPoints = polygonWeld.Polygon.Points,
							WeldCoordinateSystem = polygonWeld.GetCoordinateSystem()
						};
						polygonWeldInformationList.Add(item2);
					}
					else if (welds.Current is LogicalWeld)
					{
						Utility.MessageList.Add("GetAllWeldsFromSelectedBeamAndAddToInformationList 方法: 不支持组焊缝");
					}
				}
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x060000E7 RID: 231 RVA: 0x0000AA00 File Offset: 0x00008C00
		private static void GetAllWeldsFromSelectedPolyBeamAndAddToInformationList(PolyBeam selectedPolyBeam, ref List<Welds.WeldInformationStruct> weldInformationList, ref List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList)
		{
			selectedPolyBeam.Select();
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			TransformationPlane currentTransformationPlane2 = new TransformationPlane(selectedPolyBeam.GetCoordinateSystem());
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane2);
			ModelObjectEnumerator welds = selectedPolyBeam.GetWelds();
			if (welds.GetSize() > 0)
			{
				while (welds.MoveNext())
				{
					if (welds.Current is Weld)
					{
						Weld weld = welds.Current as Weld;
						Welds.WeldInformationStruct item = new Welds.WeldInformationStruct
						{
							Weld = weld,
							MainObject = weld.MainObject,
							SecondaryObject = weld.SecondaryObject,
							WeldPositionEnum = weld.Position,
							WeldCoordinateSystem = weld.GetCoordinateSystem()
						};
						weldInformationList.Add(item);
					}
					else if (welds.Current is PolygonWeld)
					{
						PolygonWeld polygonWeld = welds.Current as PolygonWeld;
						Welds.PolygonWeldInformationStruct item2 = new Welds.PolygonWeldInformationStruct
						{
							PolygonWeld = polygonWeld,
							MainObject = polygonWeld.MainObject,
							SecondaryObject = polygonWeld.SecondaryObject,
							PolygonWeldPoints = polygonWeld.Polygon.Points,
							WeldCoordinateSystem = polygonWeld.GetCoordinateSystem()
						};
						polygonWeldInformationList.Add(item2);
					}
					else if (welds.Current is LogicalWeld)
					{
						Utility.MessageList.Add("GetAllWeldsFromSelectedPolyBeamAndAddToInformationList method: Logical welds are not supported");
					}
				}
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x060000E8 RID: 232 RVA: 0x0000ABB4 File Offset: 0x00008DB4
		public static List<ModelObject> GetAssociativeObjects(Part selectedBeam)
		{
			List<ModelObject> result = new List<ModelObject>();
			PlateBeamConverterTools.AddToAssociativeList(selectedBeam.GetBolts(), ref result);
			PlateBeamConverterTools.AddToAssociativeList(selectedBeam.GetBooleans(), ref result);
			return result;
		}

		// Token: 0x060000E9 RID: 233 RVA: 0x0000ABEC File Offset: 0x00008DEC
		private static void GetBeamGeometricalProperties(Beam selectedBeam, out OriginalBeamProperties originalBeamPropertiesOut)
		{
			OriginalBeamProperties originalBeamProperties = new OriginalBeamProperties
			{
				BeamIdentifierGUID = selectedBeam.Identifier.GUID.ToString(),
				BeamCoordinateSystem = selectedBeam.GetCoordinateSystem(),
				BeamClass = selectedBeam.Class,
				BeamFinish = selectedBeam.Finish,
				BeamMaterial = selectedBeam.Material,
				BeamProfile = selectedBeam.Profile,
				BeamPrefix = GetValuesFromReports.GetBeamPrefix(selectedBeam),
				BeamFlangeThickness = GetValuesFromReports.GetFlangeThickness(selectedBeam),
				BeamPlateFlangeThickness = GetValuesFromReports.GetFlangePlateThickness(selectedBeam),
				BeamFlangeThickness1 = GetValuesFromReports.GetFlangeThickness1(selectedBeam),
				BeamFlangeThickness2 = GetValuesFromReports.GetFlangeThickness2(selectedBeam),
				BeamFlangeWidth1 = GetValuesFromReports.GetFlangeWidth1(selectedBeam),
				BeamFlangeWidth2 = GetValuesFromReports.GetFlangeWidth2(selectedBeam),
				BeamWebThickness = GetValuesFromReports.GetWebThickness(selectedBeam),
				BeamHeight = GetValuesFromReports.GetBeamHeight(selectedBeam),
				BeamHeight1 = GetValuesFromReports.GetBeamHeight1(selectedBeam),
				BeamHeight2 = GetValuesFromReports.GetBeamHeight2(selectedBeam),
				BeamHeight3 = GetValuesFromReports.GetBeamHeight3(selectedBeam),
				BeamHeight4 = GetValuesFromReports.GetBeamHeight4(selectedBeam),
				BeamWidth = GetValuesFromReports.GetBeamWidth(selectedBeam),
				BeamStartPoint = selectedBeam.StartPoint,
				BeamStartPointOffset = selectedBeam.StartPointOffset,
				BeamEndPoint = selectedBeam.EndPoint,
				BeamEndPointOffset = selectedBeam.EndPointOffset,
				BeamPosition = selectedBeam.Position,
				BeamTypeEnum = selectedBeam.Type,
				ColumnBottomLevel = GetValuesFromReports.GetColumnLevelsBottom(selectedBeam),
				ColumnTopLevel = GetValuesFromReports.GetColumnLevelsTop(selectedBeam)
			};
			originalBeamPropertiesOut = originalBeamProperties;
		}

		// Token: 0x060000EA RID: 234 RVA: 0x0000AD8C File Offset: 0x00008F8C
		public static List<ModelObject> GetComponents(Part selectedBeam)
		{
			List<ModelObject> result = new List<ModelObject>();
			PlateBeamConverterTools.AddToAssociativeList(selectedBeam.GetComponents(), ref result);
			return result;
		}

		// Token: 0x060000EB RID: 235 RVA: 0x0000ADB4 File Offset: 0x00008FB4
		private static string GetFlangeProfile(OriginalPolyBeamProperties properties, bool profileForUpperFlange)
		{
			double num = properties.PolyBeamWidth;
			double num2 = properties.PolyBeamFlangeThickness;
			if (num2 == 0.0)
			{
				num2 = properties.PolyBeamPlateFlangeThickness;
				if (num2 == 0.0)
				{
					num2 = properties.PolyBeamFlangeThickness1;
				}
			}
			if (num == 0.0)
			{
				num = properties.PolyBeamHeight;
			}
			string result;
			if (num <= num2)
			{
				result = string.Concat(new object[]
				{
					"PL",
					num,
					"*",
					num2
				}).Replace(",", ".");
			}
			else
			{
				result = string.Concat(new object[]
				{
					"PL",
					num2,
					"*",
					num
				}).Replace(",", ".");
			}
			return result;
		}

		// Token: 0x060000EC RID: 236 RVA: 0x0000AEC4 File Offset: 0x000090C4
		private static string GetFlangeProfile(OriginalBeamProperties properties, PlateBeamConverterTools.ProfileISubTypes subType, bool profileForUpperFlange)
		{
			string text = string.Empty;
			double num = properties.BeamWidth;
			double num2 = properties.BeamFlangeThickness;
			if (num2 == 0.0)
			{
				num2 = properties.BeamPlateFlangeThickness;
				if (num2 == 0.0)
				{
					num2 = properties.BeamFlangeThickness1;
				}
			}
			if (num == 0.0)
			{
				num = properties.BeamHeight;
			}
			if (subType != PlateBeamConverterTools.ProfileISubTypes.Normal && subType != PlateBeamConverterTools.ProfileISubTypes.Tapered)
			{
				if (subType == PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges)
				{
					text = PlateBeamConverterTools.TheFlangeProfile(properties, profileForUpperFlange, "*");
				}
			}
			else if (num <= num2)
			{
				text = string.Concat(new object[]
				{
					"PL",
					num,
					"*",
					num2
				});
			}
			else
			{
				text = string.Concat(new object[]
				{
					"PL",
					num2,
					"*",
					num
				});
			}
			return text.Replace(",", ".");
		}

		// Token: 0x060000ED RID: 237 RVA: 0x00002263 File Offset: 0x00000463
		public static void GetInputDefinitionValues(List<PluginBase.InputDefinition> inInputDefinitionList, out Beam selectedBeam)
		{
			selectedBeam = (PlateBeamConverterTools.WorkingModel.SelectModelObject(inInputDefinitionList[0].GetInput() as Identifier) as Beam);
		}

		// Token: 0x060000EE RID: 238 RVA: 0x0000B008 File Offset: 0x00009208
		private static Point GetOriginPoint(OriginalBeamProperties originalBeamProperties, double beamLength, Beam upperFlange, double halfBeamHeight, double flangeThickness2, double flangeThickness1, out LineSegment axesXLineSegment)
		{
			Point result;
			if (PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties))
			{
				Point point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - originalBeamProperties.BeamFlangeThickness, upperFlange.StartPoint.Z);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				if (flangeThickness1 > flangeThickness2)
				{
					double num = PlateBeamConverterTools.IdentifyTheBiggerValue(flangeThickness1, flangeThickness2);
					point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - num, upperFlange.StartPoint.Z);
					axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				}
				result = point;
			}
			else
			{
				Point point = new Point(beamLength, halfBeamHeight - originalBeamProperties.BeamFlangeThickness, 0.0);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				result = point;
			}
			return result;
		}

		// Token: 0x060000EF RID: 239 RVA: 0x0000B114 File Offset: 0x00009314
		private static Point GetOriginPoint(OriginalPolyBeamProperties originalBeamProperties, double beamLength, Beam upperFlange, double halfBeamHeight, double flangeThickness2, double flangeThickness1, out LineSegment axesXLineSegment)
		{
			Point result;
			if (PlateBeamConverterTools.IsTaperedHeight1BiggerThanTaperedHeight2(originalBeamProperties))
			{
				Point point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - originalBeamProperties.PolyBeamFlangeThickness, upperFlange.StartPoint.Z);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				if (flangeThickness1 > flangeThickness2)
				{
					double num = PlateBeamConverterTools.IdentifyTheBiggerValue(flangeThickness1, flangeThickness2);
					point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - num, upperFlange.StartPoint.Z);
					axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				}
				result = point;
			}
			else
			{
				Point point = new Point(beamLength, halfBeamHeight - originalBeamProperties.PolyBeamFlangeThickness, 0.0);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				result = point;
			}
			return result;
		}

		// Token: 0x060000F0 RID: 240 RVA: 0x0000B220 File Offset: 0x00009420
		private static void GetPolyBeamGeometricalProperties(PolyBeam selectedBeam, out OriginalPolyBeamProperties originalPolyBeamPropertiesOut)
		{
			OriginalPolyBeamProperties originalPolyBeamProperties = new OriginalPolyBeamProperties
			{
				PolyBeamIdentifierGUID = selectedBeam.Identifier.GUID.ToString(),
				PolyBeamCoordinateSystem = selectedBeam.GetCoordinateSystem(),
				PolyBeamSegmentCoordinateSystems = selectedBeam.GetPolybeamCoordinateSystems(),
				PolyBeamCenterLine = selectedBeam.GetCenterLine(false),
				PolyBeamClass = selectedBeam.Class,
				PolyBeamFinish = selectedBeam.Finish,
				PolyBeamMaterial = selectedBeam.Material,
				PolyBeamProfile = selectedBeam.Profile,
				PolyBeamPrefix = GetValuesFromReports.GetBeamPrefix(selectedBeam),
				PolyBeamPlateFlangeThickness = GetValuesFromReports.GetFlangePlateThickness(selectedBeam),
				PolyBeamFlangeThickness = GetValuesFromReports.GetFlangeThickness(selectedBeam),
				PolyBeamFlangeThickness1 = GetValuesFromReports.GetFlangeThickness1(selectedBeam),
				PolyBeamFlangeThickness2 = GetValuesFromReports.GetFlangeThickness2(selectedBeam),
				PolyBeamFlangeWidth1 = GetValuesFromReports.GetFlangeWidth1(selectedBeam),
				PolyBeamFlangeWidth2 = GetValuesFromReports.GetFlangeWidth2(selectedBeam),
				PolyBeamWebThickness = GetValuesFromReports.GetWebThickness(selectedBeam),
				PolyBeamHeight = GetValuesFromReports.GetBeamHeight(selectedBeam),
				PolyBeamHeight1 = GetValuesFromReports.GetBeamHeight1(selectedBeam),
				PolyBeamHeight2 = GetValuesFromReports.GetBeamHeight2(selectedBeam),
				PolyBeamHeight3 = GetValuesFromReports.GetBeamHeight3(selectedBeam),
				PolyBeamHeight4 = GetValuesFromReports.GetBeamHeight4(selectedBeam),
				PolyBeamWidth = GetValuesFromReports.GetBeamWidth(selectedBeam),
				PolyBeamPolygonPoints = selectedBeam.Contour.ContourPoints,
				PolyBeamPosition = selectedBeam.Position,
				PolyBeamTypeEnum = selectedBeam.Type,
				ColumnBottomLevel = GetValuesFromReports.GetColumnLevelsBottom(selectedBeam),
				ColumnTopLevel = GetValuesFromReports.GetColumnLevelsTop(selectedBeam)
			};
			originalPolyBeamPropertiesOut = originalPolyBeamProperties;
		}

		// Token: 0x060000F1 RID: 241 RVA: 0x0000B3B8 File Offset: 0x000095B8
		public static PlateBeamConverterTools.ProfileTypes GetProfileType(Part selectedPart)
		{
			PlateBeamConverterTools.ProfileTypes result;
			switch (PlateBeamConverterTools.IdentifyPartType(PlateBeamConverterTools.GetProfileTypeName(selectedPart)))
			{
			case PlateBeamConverterTools.ProfileTypes.ProfileI:
				result = PlateBeamConverterTools.ProfileTypes.ProfileI;
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileCorU:
				result = PlateBeamConverterTools.ProfileTypes.ProfileCorU;
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileT:
				result = PlateBeamConverterTools.ProfileTypes.ProfileT;
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection:
				result = PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection;
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileAngle:
				result = PlateBeamConverterTools.ProfileTypes.ProfileAngle;
				break;
			default:
				result = PlateBeamConverterTools.ProfileTypes.ProfileOther;
				break;
			}
			return result;
		}

		// Token: 0x060000F2 RID: 242 RVA: 0x0000B408 File Offset: 0x00009608
		private static string GetProfileTypeName(Part part)
		{
			string text = string.Empty;
			part.GetReportProperty("PROFILE_TYPE", ref text);
			string empty = string.Empty;
			part.GetReportProperty("PROFILE.SUBTYPE", ref empty);
			if (text == "Z" && empty == "1Gen.BHBeam")
			{
				text = "I";
			}
			return text;
		}

		// Token: 0x060000F3 RID: 243 RVA: 0x00002288 File Offset: 0x00000488
		private static void GetSelectedBeamPropertiesAndAssociativeObjects(Beam selectedBeam, ref OriginalBeamProperties originalBeamProperties)
		{
			PlateBeamConverterTools.GetBeamGeometricalProperties(selectedBeam, out originalBeamProperties);
			originalBeamProperties.AssociativeObjects = PlateBeamConverterTools.GetAssociativeObjects(selectedBeam);
			originalBeamProperties.Components = PlateBeamConverterTools.GetComponents(selectedBeam);
		}

		// Token: 0x060000F4 RID: 244 RVA: 0x0000B470 File Offset: 0x00009670
		private static void GetSelectedBeamPropertiesAndAssociativeObjectsInOriginalBeamsTransformationPlane(Beam selectedBeam, ref OriginalBeamProperties originalBeamProperties, ref CoordinateSystem originalBeamCoordinateSystem)
		{
			selectedBeam.Select();
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			originalBeamCoordinateSystem = selectedBeam.GetCoordinateSystem();
			TransformationPlane currentTransformationPlane2 = new TransformationPlane(originalBeamCoordinateSystem);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane2);
			PlateBeamConverterTools.GetSelectedBeamPropertiesAndAssociativeObjects(selectedBeam, ref originalBeamProperties);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x060000F5 RID: 245 RVA: 0x000022AB File Offset: 0x000004AB
		private static void GetSelectedPolyBeamPropertiesAndAssociativeObjects(PolyBeam selectedPolyBeam, ref OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			PlateBeamConverterTools.GetPolyBeamGeometricalProperties(selectedPolyBeam, out originalPolyBeamProperties);
			originalPolyBeamProperties.AssociativeObjects = PlateBeamConverterTools.GetAssociativeObjects(selectedPolyBeam);
			originalPolyBeamProperties.Components = PlateBeamConverterTools.GetComponents(selectedPolyBeam);
		}

		// Token: 0x060000F6 RID: 246 RVA: 0x0000B4D0 File Offset: 0x000096D0
		private static void GetSelectedPolyBeamPropertiesAndAssociativeObjectsInOriginalBeamsTransformationPlane(PolyBeam selectedPolyBeam, ref OriginalPolyBeamProperties originalPolyBeamProperties, ref CoordinateSystem originalPolyBeamCoordinateSystem)
		{
			selectedPolyBeam.Select();
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			originalPolyBeamCoordinateSystem = selectedPolyBeam.GetCoordinateSystem();
			TransformationPlane currentTransformationPlane2 = new TransformationPlane(originalPolyBeamCoordinateSystem);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane2);
			PlateBeamConverterTools.GetSelectedPolyBeamPropertiesAndAssociativeObjects(selectedPolyBeam, ref originalPolyBeamProperties);
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x060000F7 RID: 247 RVA: 0x0000B530 File Offset: 0x00009730
		private static double GetTheBeamHeight(OriginalBeamProperties originalBeamProperties, PlateBeamConverterTools.ProfileISubTypes subType)
		{
			double beamHeight = originalBeamProperties.BeamHeight1;
			double beamHeight2 = originalBeamProperties.BeamHeight2;
			double result;
			switch (subType)
			{
			case PlateBeamConverterTools.ProfileISubTypes.Normal:
				result = originalBeamProperties.BeamHeight;
				break;
			case PlateBeamConverterTools.ProfileISubTypes.Tapered:
				result = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2);
				break;
			case PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges:
				result = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2);
				break;
			default:
				result = 0.0;
				break;
			}
			return result;
		}

		// Token: 0x060000F8 RID: 248 RVA: 0x0000B590 File Offset: 0x00009790
		private static Point GetTheOriginPoint(Beam upperFlange, double flangeThickness1, double flangeThickness2, out LineSegment axesXLineSegment)
		{
			Point result;
			if (flangeThickness1 > flangeThickness2)
			{
				double num = PlateBeamConverterTools.IdentifyTheBiggerValue(flangeThickness1, flangeThickness2);
				Point point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - num, upperFlange.StartPoint.Z);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				result = point;
			}
			else
			{
				double num2 = PlateBeamConverterTools.IdentifyTheLowerValue(flangeThickness1, flangeThickness2);
				Point point = new Point(upperFlange.StartPoint.X, upperFlange.StartPoint.Y - num2, upperFlange.StartPoint.Z);
				axesXLineSegment = new LineSegment(new Point(upperFlange.StartPoint), new Point(upperFlange.EndPoint));
				result = point;
			}
			return result;
		}

		// Token: 0x060000F9 RID: 249 RVA: 0x0000B654 File Offset: 0x00009854
		private static string GetWebProfile(OriginalPolyBeamProperties properties, PlateBeamConverterTools.ProfileTypes profileType)
		{
			double polyBeamHeight = properties.PolyBeamHeight1;
			double polyBeamHeight2 = properties.PolyBeamHeight2;
			double num = 0.0;
			double num2 = 0.0;
			double num3 = 0.0;
			if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				num2 = properties.PolyBeamWebThickness;
				double num4 = properties.PolyBeamHeight;
				if (num4 == 0.0)
				{
					num4 = PlateBeamConverterTools.IdentifyTheLowerValue(polyBeamHeight, polyBeamHeight2);
				}
				num = properties.PolyBeamFlangeThickness;
				double num5 = 2.0 * num;
				num3 = num4 - num5;
			}
			else if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT)
			{
				num3 = properties.PolyBeamHeight - properties.PolyBeamFlangeThickness;
				num2 = properties.PolyBeamWebThickness;
			}
			else if (profileType != PlateBeamConverterTools.ProfileTypes.ProfileCorU && profileType != PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection)
			{
				if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileAngle)
				{
					double num4 = properties.PolyBeamHeight;
					if (num == 0.0)
					{
						num = properties.PolyBeamFlangeThickness1;
						if (num == 0.0)
						{
							num = properties.PolyBeamPlateFlangeThickness;
						}
					}
					num3 = num4 - num;
					num2 = properties.PolyBeamFlangeThickness1;
					if (num2 == 0.0)
					{
						num2 = properties.PolyBeamPlateFlangeThickness;
					}
				}
			}
			else
			{
				double num4 = properties.PolyBeamHeight;
				num = properties.PolyBeamFlangeThickness;
				if (num == 0.0)
				{
					num = properties.PolyBeamPlateFlangeThickness;
				}
				num2 = properties.PolyBeamWebThickness;
				if (num2 == 0.0)
				{
					num2 = properties.PolyBeamPlateFlangeThickness;
				}
				double num5 = 2.0 * num;
				num3 = num4 - num5;
			}
			string result;
			if (num2 <= num3)
			{
				result = string.Concat(new object[]
				{
					"PL",
					num2,
					"*",
					num3
				}).Replace(",", ".");
			}
			else
			{
				result = string.Concat(new object[]
				{
					"PL",
					num3,
					"*",
					num2
				}).Replace(",", ".");
			}
			return result;
		}

		// Token: 0x060000FA RID: 250 RVA: 0x0000B8E4 File Offset: 0x00009AE4
		private static string GetWebProfile(OriginalBeamProperties properties, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType)
		{
			double num = 0.0;
			double beamHeight = properties.BeamHeight1;
			double beamHeight2 = properties.BeamHeight2;
			double num2 = 0.0;
			double beamFlangeThickness = properties.BeamFlangeThickness1;
			double beamFlangeThickness2 = properties.BeamFlangeThickness2;
			double num3 = 0.0;
			double num4 = 0.0;
			double num5 = 0.0;
			if (profileType != PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileT)
				{
					num5 = properties.BeamHeight - properties.BeamFlangeThickness;
					num4 = properties.BeamWebThickness;
				}
				else if (profileType != PlateBeamConverterTools.ProfileTypes.ProfileCorU && profileType != PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection)
				{
					if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileAngle)
					{
						num = properties.BeamHeight;
						if (num2 == 0.0)
						{
							num2 = properties.BeamFlangeThickness1;
							if (num2 == 0.0)
							{
								num2 = properties.BeamPlateFlangeThickness;
							}
						}
						num5 = num - num2;
						num4 = properties.BeamFlangeThickness1;
						if (num4 == 0.0)
						{
							num4 = properties.BeamPlateFlangeThickness;
						}
					}
				}
				else
				{
					num = properties.BeamHeight;
					num2 = properties.BeamFlangeThickness;
					if (num2 == 0.0)
					{
						num2 = properties.BeamPlateFlangeThickness;
					}
					num4 = properties.BeamWebThickness;
					if (num4 == 0.0)
					{
						num4 = properties.BeamPlateFlangeThickness;
					}
					num3 = 2.0 * num2;
					num5 = num - num3;
				}
			}
			else
			{
				num4 = properties.BeamWebThickness;
				switch (subType)
				{
				case PlateBeamConverterTools.ProfileISubTypes.Normal:
					num = properties.BeamHeight;
					num2 = properties.BeamFlangeThickness;
					num3 = 2.0 * num2;
					break;
				case PlateBeamConverterTools.ProfileISubTypes.Tapered:
					num = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2);
					num2 = properties.BeamFlangeThickness;
					num3 = 2.0 * num2;
					break;
				case PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges:
				{
					num = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2);
					num2 = PlateBeamConverterTools.IdentifyTheBiggerValue(beamFlangeThickness, beamFlangeThickness2);
					double num6 = PlateBeamConverterTools.IdentifyTheLowerValue(beamFlangeThickness, beamFlangeThickness2);
					num3 = num2 + num6;
					break;
				}
				}
				num5 = num - num3;
			}
			string result;
			if (num4 <= num5)
			{
				result = string.Concat(new object[]
				{
					"PL",
					num4,
					"*",
					num5
				}).Replace(",", ".");
			}
			else
			{
				result = string.Concat(new object[]
				{
					"PL",
					num5,
					"*",
					num4
				}).Replace(",", ".");
			}
			return result;
		}

		// Token: 0x060000FB RID: 251 RVA: 0x0000BBC8 File Offset: 0x00009DC8
		private static PlateBeamConverterTools.ProfileISubTypes IdentifyIPartSubtype(OriginalBeamProperties originalBeamProperties)
		{
			PlateBeamConverterTools.ProfileISubTypes profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.Normal;
			PlateBeamConverterTools.ProfileISubTypes result;
			if (originalBeamProperties.BeamHeight != 0.0 && originalBeamProperties.BeamHeight1 == 0.0 && originalBeamProperties.BeamHeight2 == 0.0 && originalBeamProperties.BeamHeight3 == 0.0 && originalBeamProperties.BeamHeight4 == 0.0)
			{
				result = PlateBeamConverterTools.ProfileISubTypes.Normal;
			}
			else
			{
				if (originalBeamProperties.BeamHeight == 0.0 && originalBeamProperties.BeamHeight1 != 0.0 && originalBeamProperties.BeamHeight2 != 0.0 && originalBeamProperties.BeamHeight3 == 0.0 && originalBeamProperties.BeamHeight4 == 0.0)
				{
					profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.Tapered;
					if (originalBeamProperties.BeamFlangeThickness == 0.0 && originalBeamProperties.BeamFlangeThickness1 != 0.0 && originalBeamProperties.BeamFlangeThickness2 != 0.0)
					{
						profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges;
					}
				}
				result = profileISubTypes;
			}
			return result;
		}

		// Token: 0x060000FC RID: 252 RVA: 0x0000BCF8 File Offset: 0x00009EF8
		private static PlateBeamConverterTools.ProfileISubTypes IdentifyIPartSubtype(OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			PlateBeamConverterTools.ProfileISubTypes profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.Normal;
			PlateBeamConverterTools.ProfileISubTypes result;
			if (originalPolyBeamProperties.PolyBeamHeight != 0.0 && originalPolyBeamProperties.PolyBeamHeight1 == 0.0 && originalPolyBeamProperties.PolyBeamHeight2 == 0.0 && originalPolyBeamProperties.PolyBeamHeight3 == 0.0 && originalPolyBeamProperties.PolyBeamHeight4 == 0.0)
			{
				result = PlateBeamConverterTools.ProfileISubTypes.Normal;
			}
			else
			{
				if (originalPolyBeamProperties.PolyBeamHeight == 0.0 && originalPolyBeamProperties.PolyBeamHeight1 != 0.0 && originalPolyBeamProperties.PolyBeamHeight2 != 0.0 && originalPolyBeamProperties.PolyBeamHeight3 == 0.0 && originalPolyBeamProperties.PolyBeamHeight4 == 0.0)
				{
					profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.Tapered;
					if (originalPolyBeamProperties.PolyBeamFlangeThickness == 0.0 && originalPolyBeamProperties.PolyBeamFlangeThickness1 != 0.0 && originalPolyBeamProperties.PolyBeamFlangeThickness2 != 0.0)
					{
						profileISubTypes = PlateBeamConverterTools.ProfileISubTypes.TaperedWithUnequalFlanges;
					}
				}
				result = profileISubTypes;
			}
			return result;
		}

		// Token: 0x060000FD RID: 253 RVA: 0x0000BE28 File Offset: 0x0000A028
		private static PlateBeamConverterTools.ProfileTypes IdentifyPartType(string profileType)
		{
			PlateBeamConverterTools.ProfileTypes result;
			if (profileType != null)
			{
				if (profileType == "I")
				{
					result = PlateBeamConverterTools.ProfileTypes.ProfileI;
					return result;
				}
				if (profileType == "U")
				{
					result = PlateBeamConverterTools.ProfileTypes.ProfileCorU;
					return result;
				}
				if (profileType == "T")
				{
					result = PlateBeamConverterTools.ProfileTypes.ProfileT;
					return result;
				}
				if (profileType == "M")
				{
					result = PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection;
					return result;
				}
				if (profileType == "L")
				{
					result = PlateBeamConverterTools.ProfileTypes.ProfileAngle;
					return result;
				}
			}
			result = PlateBeamConverterTools.ProfileTypes.ProfileOther;
			return result;
		}

		// Token: 0x060000FE RID: 254 RVA: 0x0000BE98 File Offset: 0x0000A098
		private static double IdentifyTheBiggerValue(double value1, double value2)
		{
			return (value1 > value2) ? value1 : value2;
		}

		// Token: 0x060000FF RID: 255 RVA: 0x0000BEB4 File Offset: 0x0000A0B4
		private static double IdentifyTheLowerValue(double value1, double value2)
		{
			return (value1 < value2) ? value1 : value2;
		}

		// Token: 0x06000100 RID: 256 RVA: 0x0000BED0 File Offset: 0x0000A0D0
		public static bool InsertAssociativeObjects(List<ModelObject> associativeObjectsList, List<ModelObject> createdPlatesList, CoordinateSystem plateBeamsGeneralCoordinateSystem, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			foreach (ModelObject current in associativeObjectsList)
			{
				if (current != null)
				{
					string name = current.GetType().Name;
					switch (name)
					{
					case "BoltArray":
					case "BoltCircle":
					case "BoltXYList":
						result = (current as BoltGroup).ReMapObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem, originalBeamProperties);
						break;
					case "BooleanPart":
						result = (current as BooleanPart).InsertObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem);
						break;
					case "CutPlane":
					case "EdgeChamfer":
					case "Fitting":
						result = (current as Tekla.Structures.Model.Boolean).InsertObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem);
						break;
					}
				}
			}
			return result;
		}

		// Token: 0x06000101 RID: 257 RVA: 0x0000C030 File Offset: 0x0000A230
		public static bool InsertAssociativeObjects(List<ModelObject> associativeObjectsList, List<ModelObject> createdPlatesList, CoordinateSystem plateBeamsGeneralCoordinateSystem, OriginalPolyBeamProperties originalPolyBeamProperties)
		{
			bool result = false;
			foreach (ModelObject current in associativeObjectsList)
			{
				if (current != null)
				{
					string name = current.GetType().Name;
					switch (name)
					{
					case "BoltArray":
					case "BoltCircle":
					case "BoltXYList":
						result = (current as BoltGroup).ReMapObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem, originalPolyBeamProperties);
						break;
					case "BooleanPart":
						result = (current as BooleanPart).InsertObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem);
						break;
					case "CutPlane":
					case "EdgeChamfer":
					case "Fitting":
						result = (current as Tekla.Structures.Model.Boolean).InsertObjects(createdPlatesList, plateBeamsGeneralCoordinateSystem);
						break;
					}
				}
			}
			return result;
		}

		// Token: 0x06000102 RID: 258 RVA: 0x0000C190 File Offset: 0x0000A390
		private static void InsertAssociativeObjectsMainMethod(OriginalBeamProperties originalBeamProperties, List<ModelObject> createdPlates, CoordinateSystem plateBeamsGeneralCoordinateSystem)
		{
			List<ModelObject> associativeObjects = originalBeamProperties.AssociativeObjects;
			if (associativeObjects.Count > 0 && !PlateBeamConverterTools.InsertAssociativeObjects(associativeObjects, createdPlates, plateBeamsGeneralCoordinateSystem, originalBeamProperties))
			{
				Utility.MessageList.Add("插入相连零件的主要方法 方法失败: 相连的零件没有插入");
				Attributes.ShowMessage(LocalizationTools.Localization.GetText("相连的零件插入失败"));
			}
		}

		// Token: 0x06000103 RID: 259 RVA: 0x0000C1E8 File Offset: 0x0000A3E8
		private static void InsertAssociativeObjectsMainMethod(OriginalPolyBeamProperties originalBeamProperties, List<ModelObject> createdPlates, CoordinateSystem plateBeamsGeneralCoordinateSystem)
		{
			List<ModelObject> associativeObjects = originalBeamProperties.AssociativeObjects;
			if (associativeObjects.Count > 0 && !PlateBeamConverterTools.InsertAssociativeObjects(associativeObjects, createdPlates, plateBeamsGeneralCoordinateSystem, originalBeamProperties))
			{
				Utility.MessageList.Add("InsertAssociativeObjectsMainMethod method fail: Associative objects not inserted");
				Attributes.ShowMessage(LocalizationTools.Localization.GetText("albl_Associative_objects_insertion_failed"));
			}
		}

		// Token: 0x06000104 RID: 260 RVA: 0x0000C240 File Offset: 0x0000A440
		private static bool InsertCutPlaneForTaperedBeamCut(Beam webPlate, Vector axesX, Point originPoint)
		{
			CutPlane cutPlane = new CutPlane
			{
				Plane = new Plane()
			};
			cutPlane.Plane.Origin = new Point(originPoint);
			cutPlane.Plane.AxisX = new Vector(axesX);
			cutPlane.Plane.AxisY = new Vector(0.0, 0.0, -1000.0);
			cutPlane.Father = webPlate;
			bool result;
			if (!(result = cutPlane.Insert()))
			{
				Utility.MessageList.Add("InsertCutPlaneForTaperedBeamCut method fail: CutPlane insertion failed");
				Operation.DisplayPrompt(TeklaStructures.Environment.Localization.GetText("albl_CutPlane_insertion_failed"));
			}
			return result;
		}

		// Token: 0x06000105 RID: 261 RVA: 0x0000C2FC File Offset: 0x0000A4FC
		private static bool IsProfileWebAndFlangeThicknessAreTheSame(OriginalPolyBeamProperties originalBeamProperties)
		{
			return originalBeamProperties.PolyBeamFlangeThickness == originalBeamProperties.PolyBeamWebThickness;
		}

		// Token: 0x06000106 RID: 262 RVA: 0x0000C320 File Offset: 0x0000A520
		public static bool IsSelectedPartProfileCorU(Part selectedPart)
		{
			bool result = false;
			if (PlateBeamConverterTools.IdentifyPartType(PlateBeamConverterTools.GetProfileTypeName(selectedPart)) == PlateBeamConverterTools.ProfileTypes.ProfileCorU)
			{
				result = true;
			}
			return result;
		}

		// Token: 0x06000107 RID: 263 RVA: 0x0000C350 File Offset: 0x0000A550
		public static bool IsSelectedPartProfileI(Part selectedPart)
		{
			bool result = false;
			if (PlateBeamConverterTools.IdentifyPartType(PlateBeamConverterTools.GetProfileTypeName(selectedPart)) == PlateBeamConverterTools.ProfileTypes.ProfileI)
			{
				result = true;
			}
			return result;
		}

		// Token: 0x06000108 RID: 264 RVA: 0x0000C380 File Offset: 0x0000A580
		public static bool IsSelectedPartProfileOneOfTheSupporterdProfiles(Part selectedPart)
		{
			bool flag = false;
			PlateBeamConverterTools.ProfileTypes profileTypes = PlateBeamConverterTools.IdentifyPartType(PlateBeamConverterTools.GetProfileTypeName(selectedPart));
			return profileTypes == PlateBeamConverterTools.ProfileTypes.ProfileI || profileTypes == PlateBeamConverterTools.ProfileTypes.ProfileCorU || profileTypes == PlateBeamConverterTools.ProfileTypes.ProfileT || profileTypes == PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection || profileTypes == PlateBeamConverterTools.ProfileTypes.ProfileAngle || flag;
		}

		// Token: 0x06000109 RID: 265 RVA: 0x0000C3C8 File Offset: 0x0000A5C8
		private static bool IsTaperedHeight1BiggerThanTaperedHeight2(OriginalBeamProperties originalBeamProperties)
		{
			return originalBeamProperties.BeamHeight1 > originalBeamProperties.BeamHeight2;
		}

		// Token: 0x0600010A RID: 266 RVA: 0x0000C3EC File Offset: 0x0000A5EC
		private static bool IsTaperedHeight1BiggerThanTaperedHeight2(OriginalPolyBeamProperties originalBeamProperties)
		{
			return originalBeamProperties.PolyBeamHeight1 > originalBeamProperties.PolyBeamHeight2;
		}

		// Token: 0x0600010B RID: 267 RVA: 0x0000C410 File Offset: 0x0000A610
		private static void NormalFlangeOrientation(OriginalBeamProperties originalBeamProperties, double beamLength, Beam upperFlangePlate)
		{
			double beamHeight = originalBeamProperties.BeamHeight;
			upperFlangePlate.StartPoint = new Point(0.0, beamHeight / 2.0, 0.0);
			upperFlangePlate.EndPoint = new Point(beamLength, beamHeight / 2.0, 0.0);
		}

		// Token: 0x0600010C RID: 268 RVA: 0x0000C470 File Offset: 0x0000A670
		private static CoordinateSystem PlateBeamsGeneralCoordinateSystem(CoordinateSystem originalBeamCoordinateSystem)
		{
			return new CoordinateSystem
			{
				Origin = originalBeamCoordinateSystem.Origin,
				AxisX = new Vector(originalBeamCoordinateSystem.AxisX),
				AxisY = new Vector(originalBeamCoordinateSystem.AxisY)
			};
		}

		// Token: 0x0600010D RID: 269 RVA: 0x0000C4BC File Offset: 0x0000A6BC
		private static void RunExplodeComponentMacro(ModelObject modelObject)
		{
			if (TeklaStructures.Connect())
			{
				PlateBeamConverterTools.SelectJointInModel(modelObject);
				PlateBeamConverterTools.ExplodeSelectedComponent();
			}
		}

		// Token: 0x0600010E RID: 270 RVA: 0x0000C4E8 File Offset: 0x0000A6E8
		private static void SelectJointInModel(ModelObject modelObject)
		{
			ModelObject value = PlateBeamConverterTools.WorkingModel.SelectModelObject(modelObject.Identifier);
			ArrayList arrayList = new ArrayList();
			arrayList.Add(value);
			PlateBeamConverterTools.WorkingModelObjectSelector.Select(arrayList);
		}

		// Token: 0x0600010F RID: 271 RVA: 0x0000C524 File Offset: 0x0000A724
		private static void TaperedFlangeOrientation(OriginalBeamProperties originalBeamProperties, double beamLength, Beam upperFlangePlate)
		{
			double beamHeight = originalBeamProperties.BeamHeight1;
			double beamHeight2 = originalBeamProperties.BeamHeight2;
			double num = PlateBeamConverterTools.IdentifyTheBiggerValue(beamHeight, beamHeight2);
			double num2 = num / 2.0;
			double num3 = PlateBeamConverterTools.IdentifyTheLowerValue(beamHeight, beamHeight2);
			double flangeLocation = num2 - (num - num3);
			PlateBeamConverterTools.CalculateUpperFlangePlateStartAndEndPoint(originalBeamProperties, beamLength, upperFlangePlate, num2, flangeLocation, num);
		}

		// Token: 0x06000110 RID: 272 RVA: 0x0000C574 File Offset: 0x0000A774
		private static void TaperedFlangeOrientation(OriginalPolyBeamProperties originalBeamProperties, double beamLength, Beam upperFlangePlate)
		{
			double polyBeamHeight = originalBeamProperties.PolyBeamHeight1;
			double polyBeamHeight2 = originalBeamProperties.PolyBeamHeight2;
			double num = PlateBeamConverterTools.IdentifyTheBiggerValue(polyBeamHeight, polyBeamHeight2);
			double num2 = num / 2.0;
			double num3 = PlateBeamConverterTools.IdentifyTheLowerValue(polyBeamHeight, polyBeamHeight2);
			double flangeLocation = num2 - (num - num3);
			PlateBeamConverterTools.CalculateUpperFlangePlateStartAndEndPoint(originalBeamProperties, beamLength, upperFlangePlate, num2, flangeLocation, num);
		}

		// Token: 0x06000111 RID: 273 RVA: 0x0000C5C4 File Offset: 0x0000A7C4
		private static string TheFlangeProfile(OriginalBeamProperties properties, bool profileForUpperFlange, string sign)
		{
			string result;
			if (profileForUpperFlange)
			{
				double num = properties.BeamFlangeWidth1;
				double num2 = properties.BeamFlangeThickness1;
				result = num + sign + num2;
			}
			else
			{
				double num = properties.BeamFlangeWidth2;
				double num2 = properties.BeamFlangeThickness2;
				result = num + sign + num2;
			}
			return result;
		}

		// Token: 0x06000112 RID: 274 RVA: 0x0000C628 File Offset: 0x0000A828
		private static string TheFlangeProfile(OriginalPolyBeamProperties properties, bool profileForUpperFlange, string sign)
		{
			string result;
			if (profileForUpperFlange)
			{
				double num = properties.PolyBeamFlangeWidth1;
				double num2 = properties.PolyBeamFlangeThickness1;
				result = num + sign + num2;
			}
			else
			{
				double num = properties.PolyBeamFlangeWidth2;
				double num2 = properties.PolyBeamFlangeThickness2;
				result = num + sign + num2;
			}
			return result;
		}

		// Token: 0x06000113 RID: 275 RVA: 0x0000C68C File Offset: 0x0000A88C
		private static PolyBeam TheUpperFlenge(string platesPrefix, OriginalPolyBeamProperties originalBeamProperties)
		{
			PolyBeam polyBeam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalBeamProperties, platesPrefix);
			polyBeam.Profile.ProfileString = PlateBeamConverterTools.GetFlangeProfile(originalBeamProperties, true);
			polyBeam.Name = "上翼缘";
			polyBeam.Position.Plane = Position.PlaneEnum.RIGHT;
			polyBeam.Position.Depth = Position.DepthEnum.MIDDLE;
			polyBeam.Position.Rotation = Position.RotationEnum.BELOW;
			return polyBeam;
		}

		// Token: 0x06000114 RID: 276 RVA: 0x0000C6F0 File Offset: 0x0000A8F0
		private static Beam TheUpperFlenge(string platesPrefix, string assemblePrefix, OriginalBeamProperties originalBeamProperties, PlateBeamConverterTools.ProfileTypes profileType, PlateBeamConverterTools.ProfileISubTypes subType)
		{
			Beam beam = PlateBeamConverterTools.CreatePlateWithCommonProperties(originalBeamProperties, platesPrefix, assemblePrefix);
			beam.Profile.ProfileString = PlateBeamConverterTools.GetFlangeProfile(originalBeamProperties, subType, true);
			beam.Name = "上翼緣板";
			beam.Position.Plane = Position.PlaneEnum.RIGHT;
			beam.Position.Depth = Position.DepthEnum.MIDDLE;
			beam.Position.Rotation = Position.RotationEnum.BELOW;
			return beam;
		}

		// Token: 0x06000115 RID: 277 RVA: 0x0000C754 File Offset: 0x0000A954
		private static ArrayList TransformCenterPointsToLocalPlane(OriginalPolyBeamProperties originalBeamProperties, CoordinateSystem plateBeamsGeneralCoordinateSystem)
		{
			ArrayList arrayList = new ArrayList();
			WorkPlaneHandler workPlaneHandler = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler();
			foreach (Point p in originalBeamProperties.PolyBeamCenterLine)
			{
				TransformationPlane currentTransformationPlane = workPlaneHandler.GetCurrentTransformationPlane();
				TransformationPlane transformationPlane = new TransformationPlane(plateBeamsGeneralCoordinateSystem);
				ContourPoint value = new ContourPoint(transformationPlane.TransformationMatrixToLocal.Transform(currentTransformationPlane.TransformationMatrixToGlobal.Transform(p)), null);
				arrayList.Add(value);
			}
			return arrayList;
		}

		// Token: 0x06000116 RID: 278 RVA: 0x0000C810 File Offset: 0x0000AA10
		private static void WaitForMacro(int waitCount)
		{
			while (Operation.IsMacroRunning())
			{
				if (waitCount <= 0)
				{
					break;
				}
				waitCount--;
				Thread.Sleep(10);
			}
		}

		// Token: 0x17000025 RID: 37
		// (get) Token: 0x06000117 RID: 279 RVA: 0x0000C844 File Offset: 0x0000AA44
		// (set) Token: 0x06000118 RID: 280 RVA: 0x000022CE File Offset: 0x000004CE
		public static Model WorkingModel
		{
			get;
			set;
		}

		// Token: 0x17000026 RID: 38
		// (get) Token: 0x06000119 RID: 281 RVA: 0x0000C85C File Offset: 0x0000AA5C
		// (set) Token: 0x0600011A RID: 282 RVA: 0x000022D6 File Offset: 0x000004D6
		public static Tekla.Structures.Model.UI.ModelObjectSelector WorkingModelObjectSelector
		{
			get;
			set;
		}

		// Token: 0x02000013 RID: 19
		public enum ProfileISubTypes
		{
			// Token: 0x0400008B RID: 139
			Normal,
			// Token: 0x0400008C RID: 140
			Tapered,
			// Token: 0x0400008D RID: 141
			TaperedWithUnequalFlanges,
			// Token: 0x0400008E RID: 142
			UnEqualFlanges
		}

		// Token: 0x02000014 RID: 20
		public enum ProfileTypes
		{
			// Token: 0x04000090 RID: 144
			ProfileI,
			// Token: 0x04000091 RID: 145
			ProfileCorU,
			// Token: 0x04000092 RID: 146
			ProfileT,
			// Token: 0x04000093 RID: 147
			ProfileRectangularHollowSection,
			// Token: 0x04000094 RID: 148
			ProfileAngle,
			// Token: 0x04000095 RID: 149
			ProfileOther
		}
	}
}
