﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using CustomButton;
using Properties;
using Tekla.Structures.Internal;
using Tekla.Structures.Model;

namespace Tekla.Structures.Dialog.UIControls
{
	// Token: 0x02000006 RID: 6
	public sealed class CustomSaveLoad : UserControl
	{
		// Token: 0x14000001 RID: 1
		// (add) Token: 0x0600004B RID: 75 RVA: 0x00004250 File Offset: 0x00002450
		// (remove) Token: 0x0600004C RID: 76 RVA: 0x0000428C File Offset: 0x0000248C
		public event EventHandler AttributesLoadClicked;

		// Token: 0x14000002 RID: 2
		// (add) Token: 0x0600004D RID: 77 RVA: 0x000042C8 File Offset: 0x000024C8
		// (remove) Token: 0x0600004E RID: 78 RVA: 0x00004304 File Offset: 0x00002504
		public event EventHandler AttributesLoaded;

		// Token: 0x14000003 RID: 3
		// (add) Token: 0x0600004F RID: 79 RVA: 0x00004340 File Offset: 0x00002540
		// (remove) Token: 0x06000050 RID: 80 RVA: 0x0000437C File Offset: 0x0000257C
		public event EventHandler AttributesSaveClicked;

		// Token: 0x14000004 RID: 4
		// (add) Token: 0x06000051 RID: 81 RVA: 0x000043B8 File Offset: 0x000025B8
		// (remove) Token: 0x06000052 RID: 82 RVA: 0x000043F4 File Offset: 0x000025F4
		public event EventHandler AttributesSaved;

		// Token: 0x14000005 RID: 5
		// (add) Token: 0x06000053 RID: 83 RVA: 0x00004430 File Offset: 0x00002630
		// (remove) Token: 0x06000054 RID: 84 RVA: 0x0000446C File Offset: 0x0000266C
		public event EventHandler HelpOpenClicked;

		// Token: 0x14000006 RID: 6
		// (add) Token: 0x06000055 RID: 85 RVA: 0x000044A8 File Offset: 0x000026A8
		// (remove) Token: 0x06000056 RID: 86 RVA: 0x000044E4 File Offset: 0x000026E4
		public event EventHandler HelpOpened;

		// Token: 0x06000057 RID: 87 RVA: 0x00004520 File Offset: 0x00002720
		public CustomSaveLoad()
		{
			this.InitializeComponent();
			this.InitializeAttributeFileDirectories();
			this.Dock = DockStyle.Top;
			CustomSaveLoad.Model = new Model.Model();
			this.InvisibleBorderForCustomButtons();
		}

		// Token: 0x06000058 RID: 88 RVA: 0x00004580 File Offset: 0x00002780
		private void ComboBoxFileListUpdate()
		{
			if (base.ParentForm != null)
			{
				this.FileExtension = "." + base.ParentForm.GetType().FullName + ".xml";
				List<string> multiDirectoryFileList = EnvironmentFiles.GetMultiDirectoryFileList(this.AttributeFileDirectories, this.FileExtension);
				this.comboBoxFileList.Items.Clear();
				foreach (string current in multiDirectoryFileList)
				{
					this.comboBoxFileList.Items.Add(current);
				}
				this.comboBoxFileList.Sorted = true;
				this.comboBoxFileList.Update();
			}
		}

		// Token: 0x06000059 RID: 89 RVA: 0x00004658 File Offset: 0x00002858
		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				Form form = base.FindForm();
				if (form != null)
				{
					form.Load -= new EventHandler(this.OnParentLoaded);
				}
				if (this.components != null)
				{
					this.components.Dispose();
				}
			}
			base.Dispose(disposing);
		}

		// Token: 0x0600005A RID: 90 RVA: 0x000046B8 File Offset: 0x000028B8
		private static string GetAttributeFilePath(List<string> attributeFileList, string fileName)
		{
			string result = string.Empty;
			foreach (string current in attributeFileList)
			{
				try
				{
					if (Directory.Exists(current) && File.Exists(current + fileName))
					{
						result = current + fileName;
					}
				}
				catch (Exception ex)
				{
					string text = LocalizeForm.Localization.GetText("文件路径没有发现");
					ErrorDialog.Show(string.Format("{0} {1}", text, fileName), ex.Message, ErrorDialog.Severity.ERROR);
				}
			}
			return result;
		}

		// Token: 0x0600005B RID: 91 RVA: 0x000020E2 File Offset: 0x000002E2
		private void InitializeAttributeFileDirectories()
		{
			this.AttributeFileDirectories = EnvironmentFiles.GetStandardPropertyFileDirectories();
		}

		// Token: 0x0600005C RID: 92 RVA: 0x00004784 File Offset: 0x00002984
		private void InitializeComponent()
		{
			this.components = new Container();
			this.toolTipForButtons = new ToolTip(this.components);
			this.layout = new TableLayoutPanel();
			this.helpCustomButton = new CustomButton.CustomButton();
			this.saveCustomButton = new CustomButton.CustomButton();
			this.comboBoxFileList = new ComboBox();
			this.layout.SuspendLayout();
			base.SuspendLayout();
			this.layout.AutoSize = true;
			this.layout.AutoSizeMode = AutoSizeMode.GrowAndShrink;
			this.layout.BackgroundImage = PlateBeamConverter.Properties.Resources.FlipedBackground;
			this.layout.ColumnCount = 3;
			this.layout.ColumnStyles.Add(new ColumnStyle(SizeType.Percent, 100f));
			this.layout.ColumnStyles.Add(new ColumnStyle());
			this.layout.ColumnStyles.Add(new ColumnStyle());
			this.layout.Controls.Add(this.helpCustomButton, 2, 0);
			this.layout.Controls.Add(this.saveCustomButton, 1, 0);
			this.layout.Controls.Add(this.comboBoxFileList, 0, 0);
			this.layout.Dock = DockStyle.Fill;
			this.layout.Location = new Point(0, 0);
			this.layout.Margin = new Padding(0);
			this.layout.Name = "layout";
			this.layout.RowCount = 1;
			this.layout.RowStyles.Add(new RowStyle());
			this.layout.Size = new Size(480, 28);
			this.layout.TabIndex = 4;
			this.helpCustomButton.Anchor = (AnchorStyles.Left | AnchorStyles.Right);
			this.helpCustomButton.BackColor = Color.Transparent;
			this.helpCustomButton.BackgroundImageLayout = ImageLayout.None;
			this.helpCustomButton.DownImage = PlateBeamConverter.Properties.Resources.HelpButtonDown;
			this.helpCustomButton.FlatAppearance.BorderSize = 0;
			this.helpCustomButton.FlatStyle = FlatStyle.Flat;
			this.helpCustomButton.HoverImage = PlateBeamConverter.Properties.Resources.HelpButtonHover;
			this.helpCustomButton.Image = PlateBeamConverter.Properties.Resources.HelpButtonNormal;
			this.helpCustomButton.Location = new Point(452, 0);
			this.helpCustomButton.Margin = new Padding(0, 0, 3, 0);
			this.helpCustomButton.Name = "helpCustomButton";
			this.helpCustomButton.NormalImage = null;
			this.helpCustomButton.Size = new Size(25, 28);
			this.helpCustomButton.TabIndex = 6;
			this.helpCustomButton.UseVisualStyleBackColor = false;
			this.helpCustomButton.Click += new EventHandler(this.OnHelpClicked);
			this.saveCustomButton.Anchor = (AnchorStyles.Left | AnchorStyles.Right);
			this.saveCustomButton.BackColor = Color.Transparent;
			this.saveCustomButton.BackgroundImageLayout = ImageLayout.None;
			this.saveCustomButton.DownImage = PlateBeamConverter.Properties.Resources.SaveButtonDown;
			this.saveCustomButton.FlatAppearance.BorderSize = 0;
			this.saveCustomButton.FlatStyle = FlatStyle.Flat;
			this.saveCustomButton.HoverImage = PlateBeamConverter.Properties.Resources.SaveButtonHover;
			this.saveCustomButton.Image = PlateBeamConverter.Properties.Resources.SaveButtonNormal;
			this.saveCustomButton.Location = new Point(424, 0);
			this.saveCustomButton.Margin = new Padding(3, 0, 3, 0);
			this.saveCustomButton.Name = "saveCustomButton";
			this.saveCustomButton.NormalImage = null;
			this.saveCustomButton.Size = new Size(25, 28);
			this.saveCustomButton.TabIndex = 5;
			this.saveCustomButton.UseVisualStyleBackColor = false;
			this.saveCustomButton.Click += new EventHandler(this.OnSaveClicked);
			this.comboBoxFileList.AutoCompleteMode = AutoCompleteMode.Suggest;
			this.comboBoxFileList.AutoCompleteSource = AutoCompleteSource.ListItems;
			this.comboBoxFileList.BackColor = SystemColors.Window;
			this.comboBoxFileList.Dock = DockStyle.Fill;
			this.comboBoxFileList.FormattingEnabled = true;
			this.comboBoxFileList.Location = new Point(4, 5);
			this.comboBoxFileList.Margin = new Padding(4, 5, 3, 3);
			this.comboBoxFileList.Name = "comboBoxFileList";
			this.comboBoxFileList.Size = new Size(414, 20);
			this.comboBoxFileList.TabIndex = 2;
			this.comboBoxFileList.SelectionChangeCommitted += new EventHandler(this.OnLoadClicked);
			base.AutoScaleDimensions = new SizeF(6f, 12f);
			base.AutoScaleMode = AutoScaleMode.Font;
			base.AutoSizeMode = AutoSizeMode.GrowAndShrink;
			base.Controls.Add(this.layout);
			base.Margin = new Padding(0);
			this.MaximumSize = new Size(7500, 462);
			this.MinimumSize = new Size(200, 28);
			base.Name = "CustomSaveLoad";
			base.Size = new Size(480, 28);
			this.layout.ResumeLayout(false);
			base.ResumeLayout(false);
			base.PerformLayout();
		}

		// Token: 0x0600005D RID: 93 RVA: 0x00004CCC File Offset: 0x00002ECC
		private void InitializeFileList()
		{
			this.ComboBoxFileListUpdate();
			if (this.comboBoxFileList.Items.Contains("standard") || this.comboBoxFileList.Items.Contains("Standard"))
			{
				this.comboBoxFileList.Text = "standard";
				if (!(base.ParentForm is PluginFormBase))
				{
					this.OnLoadClicked(null, null);
				}
			}
			base.Focus();
		}

		// Token: 0x0600005E RID: 94 RVA: 0x00004D50 File Offset: 0x00002F50
		private void InvisibleBorderForCustomButtons()
		{
			this.saveCustomButton.FlatAppearance.BorderColor = Color.FromArgb(0, 255, 255, 255);
			this.helpCustomButton.FlatAppearance.BorderColor = Color.FromArgb(0, 255, 255, 255);
		}

		// Token: 0x0600005F RID: 95 RVA: 0x00004DAC File Offset: 0x00002FAC
		private void LoadStandardFileAndApplyValues(FormBase form, string fileName)
		{
			if (form != null)
			{
				string fullName = form.GetType().FullName;
				if (fullName != null)
				{
					string[] array = fullName.Split(new char[]
					{
						'.'
					});
					string text = (array.Length > 0) ? array[0] : string.Empty;
					if (Internal.Plugins.IsDrawingPlugin(text))
					{
						form.LoadValues(fileName);
					}
					else
					{
						form.ApplyValues(fileName);
					}
				}
			}
		}

		// Token: 0x06000060 RID: 96 RVA: 0x00004E28 File Offset: 0x00003028
		private void LocalizeToolTips()
		{
			string text = LocalizeForm.Localization.GetText("保存属性文件");
			this.toolTipForButtons.SetToolTip(this.saveCustomButton, text);
			string text2 = LocalizeForm.Localization.GetText("帮助");
			this.toolTipForButtons.SetToolTip(this.helpCustomButton, text2);
		}

		// Token: 0x06000061 RID: 97 RVA: 0x00004E7C File Offset: 0x0000307C
		private void OnHelpClicked(object sender, EventArgs e)
		{
			if (this.HelpOpenClicked != null)
			{
				this.HelpOpenClicked(null, null);
			}
			if (this.HelpFileType == CustomSaveLoad.HelpFileTypeEnum.UserDefined && File.Exists(this.UserDefinedHelpFilePath))
			{
				Process.Start(this.UserDefinedHelpFilePath);
			}
			else if (string.IsNullOrWhiteSpace(this.HelpUrl))
			{
//				HelpViewer.DisplayHelpTopic(this.HelpKeyword ?? string.Empty);
			}
			else
			{
				Help.ShowHelp(this, this.HelpUrl, this.HelpKeyword);
			}
			if (this.HelpOpened != null)
			{
				this.HelpOpened(null, null);
			}
		}

		// Token: 0x06000062 RID: 98 RVA: 0x00004F34 File Offset: 0x00003134
		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);
			Form form = base.FindForm();
			if (form != null)
			{
				form.Load += new EventHandler(this.OnParentLoaded);
			}
			if (!base.DesignMode)
			{
				LocalizeForm.Localization.Localize(this);
				this.LocalizeToolTips();
			}
		}

		// Token: 0x06000063 RID: 99 RVA: 0x00004F90 File Offset: 0x00003190
		private void OnLoadClicked(object sender, EventArgs e)
		{
			if (this.AttributesLoadClicked != null)
			{
				this.AttributesLoadClicked(null, null);
			}
			string text = this.comboBoxFileList.SelectedItem.ToString().Trim();
			try
			{
				if (text != string.Empty)
				{
					if (base.ParentForm is PluginFormBase)
					{
						PluginFormBase form = base.ParentForm as PluginFormBase;
						this.LoadStandardFileAndApplyValues(form, text);
					}
					else if (base.ParentForm is ApplicationFormBase)
					{
						string text2 = text + "." + base.ParentForm.GetType().FullName + ".xml";
						ApplicationFormBase applicationFormBase = base.ParentForm as ApplicationFormBase;
						if (applicationFormBase.GetConnectionStatus())
						{
							string text3 = string.Empty;
							if (!Path.IsPathRooted(text2))
							{
								text3 = CustomSaveLoad.GetAttributeFilePath(EnvironmentFiles.GetStandardPropertyFileDirectories(), text2);
							}
							if (!File.Exists(text3))
							{
								this.comboBoxFileList.Items.Remove(text);
								throw new FileNotFoundException();
							}
							applicationFormBase.ApplyValues(text3);
						}
					}
					if (this.AttributesLoaded != null)
					{
						this.AttributesLoaded(null, null);
					}
				}
			}
			catch (Exception ex)
			{
				string text4 = LocalizeForm.Localization.GetText("无法读取文件");
				ErrorDialog.Show(string.Format("{0} {1}", text4, text), ex.Message, ErrorDialog.Severity.ERROR);
			}
		}

		// Token: 0x06000064 RID: 100 RVA: 0x000020F1 File Offset: 0x000002F1
		private void OnParentLoaded(object sender, EventArgs e)
		{
			this.InitializeFileList();
		}

		// Token: 0x06000065 RID: 101 RVA: 0x0000513C File Offset: 0x0000333C
		private void OnSaveClicked(object sender, EventArgs e)
		{
			if (this.AttributesSaveClicked != null)
			{
				this.AttributesSaveClicked(null, null);
			}
			string text = this.comboBoxFileList.Text.Trim();
			try
			{
				if (text != string.Empty)
				{
					this.SaveValuesToXml(text);
					this.ComboBoxFileListUpdate();
					this.comboBoxFileList.Text = text;
					if (this.AttributesSaved != null)
					{
						this.AttributesSaved(null, null);
					}
				}
			}
			catch (Exception ex)
			{
				string text2 = LocalizeForm.Localization.GetText("无法保存文件");
				ErrorDialog.Show(string.Format("{0} {1}", text2, text), ex.Message, ErrorDialog.Severity.ERROR);
			}
		}

		// Token: 0x06000066 RID: 102 RVA: 0x00005208 File Offset: 0x00003408
		private void SaveValuesToXml(string fileName)
		{
			if (base.ParentForm is PluginFormBase)
			{
				(base.ParentForm as PluginFormBase).SaveValues(fileName);
			}
			else if (base.ParentForm is ApplicationFormBase)
			{
				string text = fileName + "." + base.ParentForm.GetType().FullName + ".xml";
				ApplicationFormBase applicationFormBase = base.ParentForm as ApplicationFormBase;
				if (applicationFormBase.GetConnectionStatus())
				{
					if (!Path.IsPathRooted(text))
					{
						text = Path.Combine(Path.Combine(CustomSaveLoad.Model.GetInfo().ModelPath, "attributes\\"), text);
					}
					if (text.Length != 0)
					{
						applicationFormBase.SaveValues(text);
					}
				}
			}
		}

		// Token: 0x17000018 RID: 24
		// (get) Token: 0x06000067 RID: 103 RVA: 0x000052E0 File Offset: 0x000034E0
		// (set) Token: 0x06000068 RID: 104 RVA: 0x000020FB File Offset: 0x000002FB
		private List<string> AttributeFileDirectories
		{
			get;
			set;
		}

		// Token: 0x17000019 RID: 25
		// (get) Token: 0x06000069 RID: 105 RVA: 0x000052F8 File Offset: 0x000034F8
		// (set) Token: 0x0600006A RID: 106 RVA: 0x00005310 File Offset: 0x00003510
		private string FileExtension
		{
			get
			{
				return this._fileExtension;
			}
			set
			{
				this._fileExtension = value.Trim(new char[]
				{
					'.'
				});
			}
		}

		// Token: 0x1700001A RID: 26
		// (get) Token: 0x0600006B RID: 107 RVA: 0x00005338 File Offset: 0x00003538
		// (set) Token: 0x0600006C RID: 108 RVA: 0x00002104 File Offset: 0x00000304
		public CustomSaveLoad.HelpFileTypeEnum HelpFileType
		{
			get;
			set;
		}

		// Token: 0x1700001B RID: 27
		// (get) Token: 0x0600006D RID: 109 RVA: 0x00005350 File Offset: 0x00003550
		// (set) Token: 0x0600006E RID: 110 RVA: 0x0000210D File Offset: 0x0000030D
		public string HelpKeyword
		{
			get
			{
				return this._helpKeyword;
			}
			set
			{
				this._helpKeyword = value;
			}
		}

		// Token: 0x1700001C RID: 28
		// (get) Token: 0x0600006F RID: 111 RVA: 0x00005368 File Offset: 0x00003568
		// (set) Token: 0x06000070 RID: 112 RVA: 0x00002117 File Offset: 0x00000317
		public string HelpUrl
		{
			get
			{
				return this._helpUrl;
			}
			set
			{
				this._helpUrl = value;
			}
		}

		// Token: 0x1700001D RID: 29
		// (get) Token: 0x06000071 RID: 113 RVA: 0x00005380 File Offset: 0x00003580
		// (set) Token: 0x06000072 RID: 114 RVA: 0x00002121 File Offset: 0x00000321
		public static Model.Model Model
		{
			get;
			set;
		}

		// Token: 0x1700001E RID: 30
		// (get) Token: 0x06000073 RID: 115 RVA: 0x00005398 File Offset: 0x00003598
		public string SaveLoadText
		{
			get
			{
				return this.comboBoxFileList.Text;
			}
		}

		// Token: 0x1700001F RID: 31
		// (get) Token: 0x06000074 RID: 116 RVA: 0x000053B8 File Offset: 0x000035B8
		// (set) Token: 0x06000075 RID: 117 RVA: 0x00002129 File Offset: 0x00000329
		public string UserDefinedHelpFilePath
		{
			get;
			set;
		}

		// Token: 0x0400000C RID: 12
		private string _fileExtension = string.Empty;

		// Token: 0x0400000D RID: 13
		private string _helpKeyword = string.Empty;

		// Token: 0x0400000E RID: 14
		private string _helpUrl = string.Empty;

		// Token: 0x0400000F RID: 15
		internal ComboBox comboBoxFileList;

		// Token: 0x04000010 RID: 16
		private IContainer components;

		// Token: 0x04000011 RID: 17
		private CustomButton.CustomButton helpCustomButton;

		// Token: 0x04000012 RID: 18
		private TableLayoutPanel layout;

		// Token: 0x04000013 RID: 19
		private CustomButton.CustomButton saveCustomButton;

		// Token: 0x04000014 RID: 20
		private ToolTip toolTipForButtons;

		// Token: 0x02000007 RID: 7
		public enum HelpFileTypeEnum
		{
			// Token: 0x04000020 RID: 32
			General,
			// Token: 0x04000021 RID: 33
			UserDefined
		}
	}
}
