﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using Tekla.Structures;
using Tekla.Structures.Dialog.UIControls;
using Tekla.Structures.Geometry3d;
using Tekla.Structures.Model;

namespace PlateBeamConverter
{
	// Token: 0x02000018 RID: 24
	public class Welds
	{
		// Token: 0x06000139 RID: 313 RVA: 0x0000CD74 File Offset: 0x0000AF74
		private static void AboveWeldProperties(Dictionary<string, string> attributeInternalNameAndValue, Weld weld)
		{
			weld.AngleAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Angle");
			int valueAsInteger = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Contour");
			weld.ContourAbove = Welds.GetWeldContour(valueAsInteger);
			weld.EffectiveThroatAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_EffectiveThroat");
			int valueAsInteger2 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Finish");
			weld.FinishAbove = Welds.GetWeldFinish(valueAsInteger2);
			weld.LengthAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Length");
			weld.PitchAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Pitch");
			weld.PrefixAboveLine = Welds.GetValueAsString(attributeInternalNameAndValue, "dia_welding_attr.SizePrefix");
			weld.RootFaceAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_RootFace");
			weld.RootOpeningAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_RootOpening");
			weld.SizeAbove = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Size");
			int valueAsInteger3 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Type");
			weld.TypeAbove = Welds.GetWeldType(valueAsInteger3);
		}

		// Token: 0x0600013A RID: 314 RVA: 0x0000CE60 File Offset: 0x0000B060
		private static void ApplyUserDefinedAttributesOnWelds(string weldAttributeName, Weld weldBetweenWebAndUpperFlange, Weld weldBetweenWebAndLowerFlange)
		{
			Dictionary<string, string> dictionary = Welds.ReadInformationFromAttributesFile(Welds.ReturnSelectedAttributesPath(weldAttributeName, ".wld.more"), weldAttributeName, ".wld.more");
			if (dictionary.Count > 0)
			{
				Welds.WeldUserDefinedAttributes(dictionary, weldBetweenWebAndUpperFlange);
				Welds.WeldUserDefinedAttributes(dictionary, weldBetweenWebAndLowerFlange);
			}
		}

		// Token: 0x0600013B RID: 315 RVA: 0x0000CEA8 File Offset: 0x0000B0A8
		private static void ApplyWeldProperties(string weldAttributeName, Weld weld)
		{
			Dictionary<string, string> dictionary = Welds.ReadInformationFromAttributesFile(Welds.ReturnSelectedAttributesPath(weldAttributeName, ".wld"), weldAttributeName, ".wld");
			if (dictionary.Count > 0)
			{
				Welds.AboveWeldProperties(dictionary, weld);
				Welds.BelowWeldProperties(dictionary, weld);
				Welds.WeldCommonProperties(dictionary, weld);
			}
		}

		// Token: 0x0600013C RID: 316 RVA: 0x0000CEF8 File Offset: 0x0000B0F8
		private static void BelowWeldProperties(Dictionary<string, string> attributeInternalNameAndValue, Weld weld)
		{
			weld.AngleBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Angle2");
			int valueAsInteger = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Contour2");
			weld.ContourBelow = Welds.GetWeldContour(valueAsInteger);
			weld.EffectiveThroatBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_EffectiveThroat2");
			int valueAsInteger2 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Finish2");
			weld.FinishBelow = Welds.GetWeldFinish(valueAsInteger2);
			weld.LengthBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Length2");
			weld.PitchBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Pitch2");
			weld.PrefixBelowLine = Welds.GetValueAsString(attributeInternalNameAndValue, "dia_welding_attr.SizePrefix2");
			weld.RootFaceBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_RootFace2");
			weld.RootOpeningBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_RootOpening2");
			weld.SizeBelow = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_Size2");
			int valueAsInteger3 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Type2");
			weld.TypeBelow = Welds.GetWeldType(valueAsInteger3);
		}

		// Token: 0x0600013D RID: 317 RVA: 0x0000CFE4 File Offset: 0x0000B1E4
		private static Weld CopyWeldPropertiesToPolygonWeld(Weld weld)
		{
			Weld weld2 = new Weld
			{
				AngleAbove = weld.AngleAbove,
				AngleBelow = weld.AngleBelow,
				AroundWeld = weld.AroundWeld,
				ConnectAssemblies = weld.ConnectAssemblies,
				ContourAbove = weld.ContourAbove,
				ContourBelow = weld.ContourBelow,
				EffectiveThroatAbove = weld.EffectiveThroatAbove,
				EffectiveThroatBelow = weld.EffectiveThroatBelow,
				ElectrodeClassification = weld.ElectrodeClassification,
				ElectrodeCoefficient = weld.ElectrodeCoefficient,
				ElectrodeStrength = weld.ElectrodeStrength,
				FinishAbove = weld.FinishAbove,
				FinishBelow = weld.FinishBelow
			};
			weld2.LengthAbove = weld.LengthAbove;
			weld2.LengthBelow = weld.LengthBelow;
			weld2.NDTInspection = weld.NDTInspection;
			weld2.PitchAbove = weld.PitchAbove;
			weld2.PitchBelow = weld.PitchBelow;
			weld2.PrefixAboveLine = weld.PrefixAboveLine;
			weld2.PrefixBelowLine = weld.PrefixBelowLine;
			weld2.ProcessType = weld.ProcessType;
			weld2.ReferenceText = weld.ReferenceText;
			weld2.RootFaceAbove = weld.RootFaceAbove;
			weld2.RootFaceBelow = weld.RootFaceBelow;
			weld2.RootOpeningAbove = weld.RootOpeningAbove;
			weld2.RootOpeningBelow = weld.RootOpeningBelow;
			weld2.ShopWeld = weld.ShopWeld;
			weld2.SizeAbove = weld.SizeAbove;
			weld2.SizeBelow = weld.SizeBelow;
			weld2.TypeAbove = weld.TypeAbove;
			weld2.TypeBelow = weld.TypeBelow;
			return weld2;
		}

		// Token: 0x0600013E RID: 318 RVA: 0x0000D194 File Offset: 0x0000B394
		private static bool CreatePolygonWelds(List<Welds.PolygonWeldInformationStruct> weldInformationList, OriginalBeamProperties originalBeamProperties, List<ModelObject> platesList)
		{
			bool result = false;
			foreach (Welds.PolygonWeldInformationStruct current in weldInformationList)
			{
				Part originalMainPart = current.MainObject as Part;
				Part originalSecondaryPart = current.SecondaryObject as Part;
				PolygonWeld polygonWeld = current.PolygonWeld;
				foreach (ModelObject current2 in platesList)
				{
					Beam beam = current2 as Beam;
					List<Point> list = new List<Point>();
					for (int i = 0; i <= current.PolygonWeldPoints.Count - 1; i++)
					{
						Point point = new Point(current.PolygonWeldPoints[i] as Point);
						if (beam != null)
						{
							Solid solid = beam.GetSolid();
							AABB aABB = new AABB(solid.MinimumPoint, solid.MaximumPoint);
							if (aABB.IsInside(point))
							{
								list.Add(point);
							}
						}
					}
					if (list.Count >= 2)
					{
						result = Welds.CreatePolygonWelds(polygonWeld, list, beam, originalMainPart, originalSecondaryPart, originalBeamProperties);
					}
				}
			}
			return result;
		}

		// Token: 0x0600013F RID: 319 RVA: 0x0000D338 File Offset: 0x0000B538
		private static bool CreatePolygonWelds(List<Welds.PolygonWeldInformationStruct> weldInformationList, OriginalPolyBeamProperties originalBeamProperties, List<ModelObject> platesList)
		{
			bool result = false;
			foreach (Welds.PolygonWeldInformationStruct current in weldInformationList)
			{
				Part originalMainPart = current.MainObject as Part;
				Part originalSecondaryPart = current.SecondaryObject as Part;
				PolygonWeld polygonWeld = current.PolygonWeld;
				List<Point> list = new List<Point>();
				for (int i = 0; i <= current.PolygonWeldPoints.Count - 1; i++)
				{
					Point point = new Point(current.PolygonWeldPoints[i] as Point);
					foreach (ModelObject current2 in platesList)
					{
						PolyBeam polyBeam = current2 as PolyBeam;
						if (polyBeam != null)
						{
							Solid solid = polyBeam.GetSolid();
							AABB aABB = new AABB(solid.MinimumPoint, solid.MaximumPoint);
							if (aABB.IsInside(point))
							{
								list.Add(point);
							}
							if (list.Count >= 2)
							{
								result = Welds.CreatePolygonWelds(polygonWeld, list, polyBeam, originalMainPart, originalSecondaryPart, originalBeamProperties);
							}
						}
					}
				}
			}
			return result;
		}

		// Token: 0x06000140 RID: 320 RVA: 0x0000D4DC File Offset: 0x0000B6DC
		private static bool CreatePolygonWelds(PolygonWeld originalPolygonWeld, List<Point> pointslist, Beam plateBeam, Part originalMainPart, Part originalSecondaryPart, OriginalBeamProperties originalBeamProperties)
		{
			bool result = false;
			if (pointslist.Count > 0)
			{
				ArrayList points = Welds.PolygonWeldPointsArrayList(pointslist);
				originalPolygonWeld.Polygon.Points = points;
				if (originalMainPart.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalPolygonWeld.MainObject = plateBeam;
					originalPolygonWeld.SecondaryObject = originalSecondaryPart;
				}
				else if (originalSecondaryPart.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					originalPolygonWeld.SecondaryObject = plateBeam;
					originalPolygonWeld.MainObject = originalMainPart;
				}
				if (!(result = originalPolygonWeld.Insert()))
				{
					string item = "CreatePolygonWelds method fail: Insertion of polygon welds failed";
					Utility.MessageList.Add(item);
					Attributes.ShowMessage(TeklaStructures.Environment.Localization.GetText("albl_Insertion_of_polygon_welds_failed"));
				}
			}
			return result;
		}

		// Token: 0x06000141 RID: 321 RVA: 0x0000D5E4 File Offset: 0x0000B7E4
		private static bool CreatePolygonWelds(PolygonWeld originalPolygonWeld, List<Point> pointslist, PolyBeam plateBeam, Part originalMainPart, Part originalSecondaryPart, OriginalPolyBeamProperties originalBeamProperties)
		{
			bool result = false;
			if (pointslist.Count > 0)
			{
				ArrayList points = Welds.PolygonWeldPointsArrayList(pointslist);
				originalPolygonWeld.Polygon.Points = points;
				if (originalMainPart.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalPolygonWeld.MainObject = plateBeam;
					originalPolygonWeld.SecondaryObject = originalSecondaryPart;
				}
				else if (originalSecondaryPart.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					originalPolygonWeld.SecondaryObject = plateBeam;
					originalPolygonWeld.MainObject = originalMainPart;
				}
				if (!(result = originalPolygonWeld.Insert()))
				{
					string item = "CreatePolygonWelds method fail: Insertion of polygon welds failed";
					Utility.MessageList.Add(item);
					Attributes.ShowMessage(TeklaStructures.Environment.Localization.GetText("albl_Insertion_of_polygon_welds_failed"));
				}
			}
			return result;
		}

		// Token: 0x06000142 RID: 322 RVA: 0x0000D6EC File Offset: 0x0000B8EC
		private static void CreatePolygonWeldsToReplaceNormalWelds(List<Welds.WeldInformationStruct> weldInformationList, OriginalBeamProperties originalBeamProperties, List<ModelObject> platesList)
		{
			foreach (Welds.WeldInformationStruct current in weldInformationList)
			{
				Weld weld = current.Weld;
				Part originalMainPart = current.MainObject as Part;
				Part originalSecondaryPart = current.SecondaryObject as Part;
				TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
				TransformationPlane transformationPlane = new TransformationPlane(weld.GetCoordinateSystem());
				List<Point> source = new List<Point>();
				List<Point> list = new List<Point>();
				foreach (ModelObject current2 in platesList)
				{
					List<Point> list2 = new List<Point>();
					Beam beam = current2 as Beam;
					if (beam != null)
					{
						Solid solid = beam.GetSolid();
						AABB @object = new AABB(solid.MinimumPoint, solid.MaximumPoint);
						list2.AddRange(source.Where(new Func<Point, bool>(@object.IsInside)));
						ArrayList pointsArrayList = Welds.PointListToArrayList(list2);
						Welds.InsertPolygonWeldToReplaceNormalWeld(originalBeamProperties, beam, originalSecondaryPart, originalMainPart, pointsArrayList, weld);
					}
				}
			}
		}

		// Token: 0x06000143 RID: 323 RVA: 0x0000D85C File Offset: 0x0000BA5C
		private static void CreatePolygonWeldsToReplaceNormalWelds(List<Welds.WeldInformationStruct> weldInformationList, OriginalPolyBeamProperties originalBeamProperties, List<ModelObject> platesList)
		{
			foreach (Welds.WeldInformationStruct current in weldInformationList)
			{
				Weld weld = current.Weld;
				Part originalMainPart = current.MainObject as Part;
				Part originalSecondaryPart = current.SecondaryObject as Part;
				TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
				TransformationPlane transformationPlane = new TransformationPlane(weld.GetCoordinateSystem());
				List<Point> source = new List<Point>();
				List<Point> list = new List<Point>();
				foreach (ModelObject current2 in platesList)
				{
					List<Point> list2 = new List<Point>();
					PolyBeam polyBeam = current2 as PolyBeam;
					if (polyBeam != null)
					{
						Solid solid = polyBeam.GetSolid();
						AABB @object = new AABB(solid.MinimumPoint, solid.MaximumPoint);
						list2.AddRange(source.Where(new Func<Point, bool>(@object.IsInside)));
						ArrayList pointsArrayList = Welds.PointListToArrayList(list2);
						Welds.InsertPolygonWeldToReplaceNormalWeld(originalBeamProperties, polyBeam, originalSecondaryPart, originalMainPart, pointsArrayList, weld);
					}
				}
			}
		}

		// Token: 0x06000144 RID: 324 RVA: 0x0000D9CC File Offset: 0x0000BBCC
		private static Weld CreatePolygonWeldToReplaceWeld(Weld weld, Part originalMainPart, Part originalSecondaryPart, Beam plateBeam, OriginalBeamProperties originalBeamProperties, ArrayList polygonPointsArrayList)
		{
			Weld weld2 = Welds.CopyWeldPropertiesToPolygonWeld(weld);
			Weld result;
			if (originalMainPart.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
			{
				weld2.MainObject = plateBeam;
				weld2.SecondaryObject = originalSecondaryPart;
				result = weld2;
			}
			else
			{
				if (originalSecondaryPart.Identifier.GUID.ToString() == originalBeamProperties.BeamIdentifierGUID)
				{
					weld2.MainObject = originalMainPart;
					weld2.SecondaryObject = plateBeam;
				}
				result = weld2;
			}
			return result;
		}

		// Token: 0x06000145 RID: 325 RVA: 0x0000DA68 File Offset: 0x0000BC68
		private static Weld CreatePolygonWeldToReplaceWeld(Weld weld, Part originalMainPart, Part originalSecondaryPart, PolyBeam plateBeam, OriginalPolyBeamProperties originalBeamProperties, ArrayList polygonPointsArrayList)
		{
			Weld weld2 = Welds.CopyWeldPropertiesToPolygonWeld(weld);
			Weld result;
			if (originalMainPart.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
			{
				weld2.MainObject = plateBeam;
				weld2.SecondaryObject = originalSecondaryPart;
				result = weld2;
			}
			else
			{
				if (originalSecondaryPart.Identifier.GUID.ToString() == originalBeamProperties.PolyBeamIdentifierGUID)
				{
					weld2.MainObject = originalMainPart;
					weld2.SecondaryObject = plateBeam;
				}
				result = weld2;
			}
			return result;
		}

		// Token: 0x06000146 RID: 326 RVA: 0x0000DB04 File Offset: 0x0000BD04
		private static Weld CreateWeldsBetweenWebAndFlanges(string weldAttributeName, ModelObject mainObject, ModelObject secondaryObject)
		{
			Weld weld = new Weld
			{
				MainObject = mainObject,
				SecondaryObject = secondaryObject
			};
			Welds.ApplyWeldProperties(weldAttributeName, weld);
			return weld;
		}

		// Token: 0x06000147 RID: 327 RVA: 0x0000DB38 File Offset: 0x0000BD38
		public static bool CreateWeldsBetweenWebAndFlangesMainMethod(PlateBeamConverterTools.ProfileTypes profileType, List<ModelObject> platesList, string weldAttributeName)
		{
			ModelObject mainObject = platesList[0];
			ModelObject secondaryObject = platesList[1];
			Weld weld = new Weld();
			Weld weld2 = new Weld();
			Weld weld3 = new Weld();
			Weld weld4 = new Weld();
			bool flag = false;
			switch (profileType)
			{
			case PlateBeamConverterTools.ProfileTypes.ProfileI:
			case PlateBeamConverterTools.ProfileTypes.ProfileCorU:
			{
				ModelObject secondaryObject2 = platesList[2];
				weld = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject);
				weld2 = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject2);
				flag = (weld.Insert() && weld2.Insert());
				break;
			}
			case PlateBeamConverterTools.ProfileTypes.ProfileT:
				flag = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject).Insert();
				break;
			case PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection:
			{
				ModelObject secondaryObject3 = platesList[2];
				ModelObject mainObject2 = platesList[3];
				weld = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject);
				weld2 = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject3);
				weld3 = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject2, secondaryObject);
				weld4 = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject2, secondaryObject3);
				flag = (weld.Insert() && weld2.Insert() && weld3.Insert() && weld4.Insert());
				break;
			}
			case PlateBeamConverterTools.ProfileTypes.ProfileAngle:
			{
				ModelObject secondaryObject4 = platesList[1];
				weld = Welds.CreateWeldsBetweenWebAndFlanges(weldAttributeName, mainObject, secondaryObject4);
				flag = weld.Insert();
				break;
			}
			}
			bool result;
			if (flag)
			{
				Welds.ApplyUserDefinedAttributesOnWelds(weldAttributeName, weld, weld2);
				if (profileType == PlateBeamConverterTools.ProfileTypes.ProfileRectangularHollowSection)
				{
					Welds.ApplyUserDefinedAttributesOnWelds(weldAttributeName, weld3, weld4);
				}
				result = flag;
			}
			else
			{
				Utility.MessageList.Add("CreateWeldsBetweenWebAndFlangesMainMethod method fail: Welds between web and flanges not inserted");
				Attributes.ShowMessage(TeklaStructures.Environment.Localization.GetText("albl_Welds_between_web_and_flanges_not_inserted"));
				result = flag;
			}
			return result;
		}

		// Token: 0x06000148 RID: 328 RVA: 0x0000DCCC File Offset: 0x0000BECC
		private static double GetValueAsDouble(Dictionary<string, string> attributeInternalNameAndValue, string nameKey)
		{
			return Parsers.ParseDouble(Welds.GetValueFromAttribute(attributeInternalNameAndValue, nameKey));
		}

		// Token: 0x06000149 RID: 329 RVA: 0x0000DCEC File Offset: 0x0000BEEC
		private static int GetValueAsInteger(Dictionary<string, string> attributeInternalNameAndValue, string nameKey)
		{
			return Parsers.ParseInt(Welds.GetValueFromAttribute(attributeInternalNameAndValue, nameKey));
		}

		// Token: 0x0600014A RID: 330 RVA: 0x0000DD0C File Offset: 0x0000BF0C
		private static string GetValueAsString(Dictionary<string, string> attributeInternalNameAndValue, string nameKey)
		{
			return Welds.GetValueFromAttribute(attributeInternalNameAndValue, nameKey).Replace("\"", string.Empty);
		}

		// Token: 0x0600014B RID: 331 RVA: 0x0000DD34 File Offset: 0x0000BF34
		private static string GetValueFromAttribute(Dictionary<string, string> attributeInternalNameAndValue, string key)
		{
			string result = string.Empty;
			if (attributeInternalNameAndValue.ContainsKey(key))
			{
				result = attributeInternalNameAndValue[key];
			}
			return result;
		}

		// Token: 0x0600014C RID: 332 RVA: 0x0000DD68 File Offset: 0x0000BF68
		private static StringBuilder GetValues(string[] tokens)
		{
			StringBuilder stringBuilder = new StringBuilder();
			for (int i = 1; i < tokens.Length; i++)
			{
				stringBuilder.Append(tokens[i] + " ");
			}
			return stringBuilder;
		}

		// Token: 0x0600014D RID: 333 RVA: 0x0000DDAC File Offset: 0x0000BFAC
		private static BaseWeld.WeldContourEnum GetWeldContour(int contourIndex)
		{
			BaseWeld.WeldContourEnum weldContourEnum = BaseWeld.WeldContourEnum.WELD_CONTOUR_NONE;
			BaseWeld.WeldContourEnum result;
			switch (contourIndex)
			{
			case 0:
				result = BaseWeld.WeldContourEnum.WELD_CONTOUR_NONE;
				break;
			case 1:
				result = BaseWeld.WeldContourEnum.WELD_CONTOUR_FLUSH;
				break;
			case 2:
				result = BaseWeld.WeldContourEnum.WELD_CONTOUR_CONVEX;
				break;
			case 3:
				result = BaseWeld.WeldContourEnum.WELD_CONTOUR_CONCAVE;
				break;
			default:
				result = weldContourEnum;
				break;
			}
			return result;
		}

		// Token: 0x0600014E RID: 334 RVA: 0x0000DDEC File Offset: 0x0000BFEC
		private static BaseWeld.WeldElectrodeClassificationEnum GetWeldElectrodeClassification(int electrodeClassificationIndex)
		{
			BaseWeld.WeldElectrodeClassificationEnum weldElectrodeClassificationEnum = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_NONE;
			BaseWeld.WeldElectrodeClassificationEnum result;
			switch (electrodeClassificationIndex)
			{
			case 0:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_NONE;
				break;
			case 1:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_35;
				break;
			case 2:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_42;
				break;
			case 3:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_50;
				break;
			case 4:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_E60XX;
				break;
			case 5:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_E70XX;
				break;
			case 6:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_E80XX;
				break;
			case 7:
				result = BaseWeld.WeldElectrodeClassificationEnum.WELD_ELECTRODE_CLASSIFICATION_E90XX;
				break;
			default:
				result = weldElectrodeClassificationEnum;
				break;
			}
			return result;
		}

		// Token: 0x0600014F RID: 335 RVA: 0x0000DE4C File Offset: 0x0000C04C
		private static BaseWeld.WeldFinishEnum GetWeldFinish(int finishIndex)
		{
			BaseWeld.WeldFinishEnum weldFinishEnum = BaseWeld.WeldFinishEnum.WELD_FINISH_NONE;
			BaseWeld.WeldFinishEnum result;
			switch (finishIndex)
			{
			case 0:
				result = BaseWeld.WeldFinishEnum.WELD_FINISH_NONE;
				break;
			case 1:
				result = BaseWeld.WeldFinishEnum.WELD_FINISH_GRIND;
				break;
			case 2:
				result = BaseWeld.WeldFinishEnum.WELD_FINISH_MACHINE;
				break;
			case 3:
				result = BaseWeld.WeldFinishEnum.WELD_FINISH_CHIP;
				break;
			case 4:
				result = BaseWeld.WeldFinishEnum.WELD_FINISH_FINISHED_WELD;
				break;
			case 5:
				result = BaseWeld.WeldFinishEnum.WELS_FINISH_SMOOTH_TRANSITION;
				break;
			default:
				result = weldFinishEnum;
				break;
			}
			return result;
		}

		// Token: 0x06000150 RID: 336 RVA: 0x0000DE9C File Offset: 0x0000C09C
		private static BaseWeld.WeldNDTInspectionEnum GetWeldNdtInspection(int index)
		{
			BaseWeld.WeldNDTInspectionEnum weldNDTInspectionEnum = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_NONE;
			BaseWeld.WeldNDTInspectionEnum result;
			switch (index)
			{
			case 0:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_NONE;
				break;
			case 1:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_A;
				break;
			case 2:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_B;
				break;
			case 3:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_C;
				break;
			case 4:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_D;
				break;
			case 5:
				result = BaseWeld.WeldNDTInspectionEnum.WELD_NDT_INSPECTION_E;
				break;
			default:
				result = weldNDTInspectionEnum;
				break;
			}
			return result;
		}

		// Token: 0x06000151 RID: 337 RVA: 0x0000DEEC File Offset: 0x0000C0EC
		private static Weld.WeldPositionEnum GetWeldPosition(int index)
		{
			Weld.WeldPositionEnum weldPositionEnum = Weld.WeldPositionEnum.WELD_POSITION_PLUS_Z;
			Weld.WeldPositionEnum result;
			switch (index)
			{
			case 1:
				result = Weld.WeldPositionEnum.WELD_POSITION_PLUS_X;
				break;
			case 2:
				result = Weld.WeldPositionEnum.WELD_POSITION_MINUS_X;
				break;
			case 3:
				result = Weld.WeldPositionEnum.WELD_POSITION_PLUS_Y;
				break;
			case 4:
				result = Weld.WeldPositionEnum.WELD_POSITION_MINUS_Y;
				break;
			case 5:
				result = Weld.WeldPositionEnum.WELD_POSITION_PLUS_Z;
				break;
			case 6:
				result = Weld.WeldPositionEnum.WELD_POSITION_MINUS_Z;
				break;
			default:
				result = weldPositionEnum;
				break;
			}
			return result;
		}

		// Token: 0x06000152 RID: 338 RVA: 0x0000DF40 File Offset: 0x0000C140
		private static BaseWeld.WeldProcessTypeEnum GetWeldProcessType(int index)
		{
			BaseWeld.WeldProcessTypeEnum weldProcessTypeEnum = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_NONE;
			BaseWeld.WeldProcessTypeEnum result;
			switch (index)
			{
			case 0:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_NONE;
				break;
			case 1:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_SMAW;
				break;
			case 2:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_SAW;
				break;
			case 3:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_GMAW;
				break;
			case 4:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_FCAW;
				break;
			case 5:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_ESW;
				break;
			case 6:
				result = BaseWeld.WeldProcessTypeEnum.WELD_PROCESS_EGW;
				break;
			default:
				result = weldProcessTypeEnum;
				break;
			}
			return result;
		}

		// Token: 0x06000153 RID: 339 RVA: 0x0000DF98 File Offset: 0x0000C198
		private static BaseWeld.WeldTypeEnum GetWeldType(int finishIndex)
		{
			BaseWeld.WeldTypeEnum weldTypeEnum = BaseWeld.WeldTypeEnum.WELD_TYPE_NONE;
			BaseWeld.WeldTypeEnum result;
			switch (finishIndex)
			{
			case 0:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_NONE;
				break;
			case 1:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_EDGE_FLANGE;
				break;
			case 2:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SQUARE_GROOVE_SQUARE_BUTT;
				break;
			case 3:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_BEVEL_GROOVE_SINGLE_V_BUTT;
				break;
			case 4:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_BEVEL_GROOVE_SINGLE_BEVEL_BUTT;
				break;
			case 5:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SINGLE_V_BUTT_WITH_BROAD_ROOT_FACE;
				break;
			case 6:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SINGLE_BEVEL_BUTT_WITH_BROAD_ROOT_FACE;
				break;
			case 7:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_U_GROOVE_SINGLE_U_BUTT;
				break;
			case 8:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_J_GROOVE_J_BUTT;
				break;
			case 9:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_BEVEL_BACKING;
				break;
			case 10:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_FILLET;
				break;
			case 11:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_PLUG;
				break;
			case 12:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SPOT;
				break;
			case 13:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SEAM;
				break;
			case 14:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_SLOT;
				break;
			case 15:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_FLARE_BEVEL_GROOVE;
				break;
			case 16:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_FLARE_V_GROOVE;
				break;
			case 17:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_CORNER_FLANGE;
				break;
			case 18:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_PARTIAL_PENETRATION_SINGLE_BEVEL_BUTT_PLUS_FILLET;
				break;
			case 19:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_PARTIAL_PENETRATION_SQUARE_GROOVE_PLUS_FILLET;
				break;
			case 20:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_MELT_THROUGH;
				break;
			case 21:
				result = BaseWeld.WeldTypeEnum.STEEP_FLANKED_BEVEL_GROOVE_SINGLE_V_BUTT;
				break;
			case 22:
				result = BaseWeld.WeldTypeEnum.STEEP_FLANKED_BEVEL_GROOVE_SINGLE_BEVEL_BUTT;
				break;
			case 23:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_EDGE;
				break;
			case 24:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_ISO_SURFACING;
				break;
			case 25:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_FOLD;
				break;
			case 26:
				result = BaseWeld.WeldTypeEnum.WELD_TYPE_INCLINED;
				break;
			default:
				result = weldTypeEnum;
				break;
			}
			return result;
		}

		// Token: 0x06000154 RID: 340 RVA: 0x0000E0A4 File Offset: 0x0000C2A4
		private static bool InsertPolygonWeldToReplaceNormalWeld(OriginalBeamProperties originalBeamProperties, Beam plateBeam, Part originalSecondaryPart, Part originalMainPart, ArrayList pointsArrayList, Weld weld)
		{
			bool result;
			if (!(result = Welds.CreatePolygonWeldToReplaceWeld(weld, originalMainPart, originalSecondaryPart, plateBeam, originalBeamProperties, pointsArrayList).Insert()))
			{
				Utility.MessageList.Add("InsertPolygonWeldToReplaceNormalWeld method fail: Polygon weld not inserted");
			}
			return result;
		}

		// Token: 0x06000155 RID: 341 RVA: 0x0000E0E4 File Offset: 0x0000C2E4
		private static bool InsertPolygonWeldToReplaceNormalWeld(OriginalPolyBeamProperties originalBeamProperties, PolyBeam plateBeam, Part originalSecondaryPart, Part originalMainPart, ArrayList pointsArrayList, Weld weld)
		{
			bool result;
			if (!(result = Welds.CreatePolygonWeldToReplaceWeld(weld, originalMainPart, originalSecondaryPart, plateBeam, originalBeamProperties, pointsArrayList).Insert()))
			{
				Utility.MessageList.Add("InsertPolygonWeldToReplaceNormalWeld method fail: Polygon weld not inserted");
			}
			return result;
		}

		// Token: 0x06000156 RID: 342 RVA: 0x0000E124 File Offset: 0x0000C324
		private static bool IsWeldAround(int aroundIndex)
		{
			bool flag = false;
			bool result;
			switch (aroundIndex)
			{
			case 0:
				result = flag;
				break;
			case 1:
				result = true;
				break;
			default:
				result = flag;
				break;
			}
			return result;
		}

		// Token: 0x06000157 RID: 343 RVA: 0x0000E124 File Offset: 0x0000C324
		private static bool IsWeldWorkshopWeld(int index)
		{
			bool flag = false;
			bool result;
			switch (index)
			{
			case 0:
				result = flag;
				break;
			case 1:
				result = true;
				break;
			default:
				result = flag;
				break;
			}
			return result;
		}

		// Token: 0x06000158 RID: 344 RVA: 0x0000E154 File Offset: 0x0000C354
		private static ArrayList PointListToArrayList(List<Point> pointsList)
		{
			ArrayList arrayList = new ArrayList();
			foreach (Point current in pointsList)
			{
				arrayList.Add(current);
			}
			return arrayList;
		}

		// Token: 0x06000159 RID: 345 RVA: 0x0000E154 File Offset: 0x0000C354
		private static ArrayList PolygonWeldPointsArrayList(List<Point> pointslist)
		{
			ArrayList arrayList = new ArrayList();
			foreach (Point current in pointslist)
			{
				arrayList.Add(current);
			}
			return arrayList;
		}

		// Token: 0x0600015A RID: 346 RVA: 0x0000E1B8 File Offset: 0x0000C3B8
		private static Dictionary<string, string> ReadInformationFromAttributesFile(string filePath, string fileName, string fileExtension)
		{
			Dictionary<string, string> dictionary = new Dictionary<string, string>();
			string path = filePath + fileName + fileExtension;
			if (File.Exists(path))
			{
				using (StreamReader streamReader = new StreamReader(path))
				{
					string text;
					while ((text = streamReader.ReadLine()) != null)
					{
						string[] array = text.Split(new char[]
						{
							' '
						});
						int num = array.Length;
						StringBuilder values = Welds.GetValues(array);
						if (num != 0 && num != 1 && num > 0)
						{
							dictionary.Add(array[0], values.ToString());
						}
					}
				}
			}
			return dictionary;
		}

		// Token: 0x0600015B RID: 347 RVA: 0x0000E28C File Offset: 0x0000C48C
		private static string ReturnSelectedAttributesPath(string attributeName, string extension)
		{
			List<string> standardPropertyFileDirectories = EnvironmentFiles.GetStandardPropertyFileDirectories();
			string result = string.Empty;
			bool flag = false;
			foreach (string current in standardPropertyFileDirectories)
			{
				if (!flag && File.Exists(current + attributeName + extension))
				{
					result = current;
					flag = true;
				}
			}
			return result;
		}

		// Token: 0x0600015C RID: 348 RVA: 0x0000E318 File Offset: 0x0000C518
		private static void WeldCommonProperties(Dictionary<string, string> attributeInternalNameAndValue, Weld weld)
		{
			int valueAsInteger = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_AroundWeld");
			weld.AroundWeld = Welds.IsWeldAround(valueAsInteger);
			int valueAsInteger2 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_ElectrodeClass");
			weld.ElectrodeClassification = Welds.GetWeldElectrodeClassification(valueAsInteger2);
			weld.ElectrodeCoefficient = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_ElectrodeCoefficient");
			weld.ElectrodeStrength = Welds.GetValueAsDouble(attributeInternalNameAndValue, "dia_welding_attr.w_ElectrodeStrength");
			int valueAsInteger3 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Shape");
			int valueAsInteger4 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_NDTInspection");
			weld.NDTInspection = Welds.GetWeldNdtInspection(valueAsInteger4);
			int valueAsInteger5 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Placement");
			int valueAsInteger6 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_Position");
			weld.Position = Welds.GetWeldPosition(valueAsInteger6);
			int valueAsInteger7 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_WeldingProcessType");
			weld.ProcessType = Welds.GetWeldProcessType(valueAsInteger7);
			weld.ReferenceText = Welds.GetValueAsString(attributeInternalNameAndValue, "dia_welding_attr.w_ReferenceText");
			int valueAsInteger8 = Welds.GetValueAsInteger(attributeInternalNameAndValue, "dia_welding_attr.w_WorkshopWeld");
			weld.ShopWeld = Welds.IsWeldWorkshopWeld(valueAsInteger8);
		}

		// Token: 0x0600015D RID: 349 RVA: 0x0000E414 File Offset: 0x0000C614
		public static void WeldsAndPolygonWeldsToPlateBeams(List<ModelObject> platesList, List<Welds.WeldInformationStruct> weldInformationList, List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList, OriginalBeamProperties originalBeamProperties, CoordinateSystem plateBeamsGeneralCoordinateSystem, PlateBeamConverterTools.ProfileTypes profileType)
		{
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			if (weldInformationList.Count > 0)
			{
				Welds.CreatePolygonWeldsToReplaceNormalWelds(weldInformationList, originalBeamProperties, platesList);
			}
			if (polygonWeldInformationList.Count > 0)
			{
				Welds.CreatePolygonWelds(polygonWeldInformationList, originalBeamProperties, platesList);
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x0600015E RID: 350 RVA: 0x0000E47C File Offset: 0x0000C67C
		public static void WeldsAndPolygonWeldsToPlateBeams(List<ModelObject> platesList, List<Welds.WeldInformationStruct> weldInformationList, List<Welds.PolygonWeldInformationStruct> polygonWeldInformationList, OriginalPolyBeamProperties originalPolyBeamProperties, CoordinateSystem plateBeamsGeneralCoordinateSystem, PlateBeamConverterTools.ProfileTypes profileType)
		{
			TransformationPlane currentTransformationPlane = PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().GetCurrentTransformationPlane();
			if (weldInformationList.Count > 0)
			{
				Welds.CreatePolygonWeldsToReplaceNormalWelds(weldInformationList, originalPolyBeamProperties, platesList);
			}
			if (polygonWeldInformationList.Count > 0)
			{
				Welds.CreatePolygonWelds(polygonWeldInformationList, originalPolyBeamProperties, platesList);
			}
			PlateBeamConverterTools.WorkingModel.GetWorkPlaneHandler().SetCurrentTransformationPlane(currentTransformationPlane);
		}

		// Token: 0x0600015F RID: 351 RVA: 0x0000E4E4 File Offset: 0x0000C6E4
		private static void WeldUserDefinedAttributes(Dictionary<string, string> attributeInternalNameAndValue, Weld weld)
		{
			List<string> list = new List<string>(attributeInternalNameAndValue.Keys);
			foreach (string current in list)
			{
				string name = current.Replace("welding_attributes.", string.Empty);
				string text;
				attributeInternalNameAndValue.TryGetValue(current, out text);
				string value = text.Replace("\"", string.Empty);
				weld.SetUserProperty(name, value);
			}
		}

		// Token: 0x02000019 RID: 25
		public struct PolygonWeldInformationStruct
		{
			// Token: 0x0400009C RID: 156
			public PolygonWeld PolygonWeld;

			// Token: 0x0400009D RID: 157
			public ModelObject MainObject;

			// Token: 0x0400009E RID: 158
			public ModelObject SecondaryObject;

			// Token: 0x0400009F RID: 159
			public ArrayList PolygonWeldPoints;

			// Token: 0x040000A0 RID: 160
			public CoordinateSystem WeldCoordinateSystem;
		}

		// Token: 0x0200001A RID: 26
		public struct WeldInformationStruct
		{
			// Token: 0x040000A1 RID: 161
			public Weld Weld;

			// Token: 0x040000A2 RID: 162
			public ModelObject MainObject;

			// Token: 0x040000A3 RID: 163
			public ModelObject SecondaryObject;

			// Token: 0x040000A4 RID: 164
			public Weld.WeldPositionEnum WeldPositionEnum;

			// Token: 0x040000A5 RID: 165
			public CoordinateSystem WeldCoordinateSystem;
		}
	}
}
